/// <amd-module name="@cxl/ui/appbar.js" />
import { Component } from './component.js';
import { SurfaceColorValue } from './theme.js';
/**
 * Appbar is a core component that sits at the top of your application's layout.
 * It displays essential information, navigation, and actions relevant to the current screen.
 *
 * Prominently displays your application's logo or title for branding and context.
 * Integrates navigation elements like Navbar or components for user navigation.
 * Supports contextual menus via `cxl-appbar-contextual` components.
 *
 * Related Components:
 *
 * - cxl-appbar-title: Sets the title text within the Appbar.
 * - cxl-navbar: A navigation bar component suitable for placement within the Appbar.
 * - cxl-appbar-contextual: Defines a contextual menu associated with the Appbar.
 *
 * @see AppbarTitle
 * @see Navbar
 * @see AppbarContextual
 *
 * @demo
 * <cxl-appbar>
 *   <cxl-navbar></cxl-navbar>
 *   <cxl-appbar-title>Appbar Title</cxl-appbar-title>
 * </cxl-appbar>
 *
 * @demo <caption>Appbar with Tabs</caption>
 * <cxl-appbar>
 *   <cxl-navbar></cxl-navbar>
 *   <cxl-appbar-title>Appbar with Tabs</cxl-appbar-title>
 *   <cxl-tabs>
 *     <cxl-tab selected>Tab 1</cxl-tab>
 *     <cxl-tab>Tab 2</cxl-tab>
 *     <cxl-tab>Tab 3</cxl-tab>
 *   </cxl-tabs>
 * </cxl-appbar>
 *
 * @see AppbarTitle
 */
export declare class Appbar extends Component {
    /**
     * Extends the appbar height.
     * @demo
     * <cxl-appbar extended>
     *   <cxl-navbar></cxl-navbar>
     *   <cxl-appbar-title>Appbar Title</cxl-appbar-title>
     *   <cxl-avatar alt=""></cxl-avatar>
     * </cxl-appbar>
     */
    extended: boolean;
    /**
     * Centers Appbar in large screens
     */
    center: boolean;
    /**
     * Sets or gets the active contextual menu.
     * @see AppbarContextual
     * @demo
     * <cxl-appbar contextual="test">
     * <cxl-appbar-title>Appbar Title</cxl-appbar-title>
     * <cxl-appbar-contextual name="test">Contextual Appbar</cxl-appbar-contextual>
     * </cxl-appbar>
     */
    contextual?: string;
    /**
     * Enables sticky mode.
     */
    sticky: boolean;
    /**
     * Removes elevation
     */
    flat: boolean;
    /** Sets the component color */
    color?: SurfaceColorValue;
}
/**
 * A top app bar can transform into a contextual action bar to provide contextual actions to selected items. Upon closing, the contextual action bar transforms back into a top app bar.
 * @see Appbar
 * @demo
 * <cxl-appbar contextual="test">
 *   <cxl-appbar-title>Appbar Title</cxl-appbar-title>
 *   <cxl-appbar-contextual name="test">Contextual Appbar</cxl-appbar-contextual>
 * </cxl-appbar>
 */
export declare class AppbarContextual extends Component {
    /**
     * The name of the contextual menu. Used by the contextual property of the Appbar component.
     */
    name?: string;
    /**
     * Determines the visibility of the component when attached to an Appbar.
     */
    visible: boolean;
}
/**
 * @see Appbar
 */
export declare class AppbarTitle extends Component {
}
