/// <amd-module name="@cxl/ui/calendar.js" />
import { Component } from './component.js';
import { DateInformation } from './calendar-date.js';
import { CalendarMonth } from './calendar-month.js';
import { CalendarEvent } from './calendar-event.js';
import { CalendarDay } from './calendar-day.js';
import type { CalendarEventData } from './calendar-event.js';
declare module './registable.js' {
    interface RegistableMap {
        calendar: (calendar: CalendarBase) => void;
        'calendar.event': CalendarEvent;
    }
}
declare module './dom.js' {
    interface CustomEventMap {
        'calendar.clickevent': CalendarEventData;
        'calendar.showmore': DateInformation;
        'calendar.clickdate': Date;
    }
}
export declare class CalendarNavigation extends Component {
    calendar?: CalendarBase;
}
export declare class CalendarSelectView extends Component {
    calendar?: CalendarBase;
}
export declare class CalendarDateText extends Component {
    calendar?: CalendarBase;
}
/**
 * This is an abstract base class for calendar components.
 */
export declare abstract class CalendarBase extends Component {
    /**
     * An array of events to be displayed on the calendar.
     */
    events: CalendarEventData[];
    /**
     * The currently selected date in the calendar.
     */
    value: Date;
    /**
     * The current view of the calendar.
     */
    view: 'month' | 'day' | 'week';
    /**
     * This event is triggered when a user clicks on an event in the calendar.
     * The event handler receives a `CustomEvent` containing the clicked `CalendarEventData`.
     */
    oneventclick?: (ev: CustomEvent<CalendarEventData>) => void;
    /**
     * This readonly property reflects the currently active view based on the `view` property.
     * It can be a `CalendarMonth` object for the month view, or a `CalendarDay` object for the day view,
     */
    readonly activeView?: CalendarMonth | CalendarDay;
    /**
     * This abstract method should be implemented by concrete calendar subclasses.
     * It should return a DOM node representing the header of the calendar.
     */
    protected abstract getHeader?(): Node;
    /**
     * This abstract method should be implemented by concrete calendar subclasses.
     * It should return a DOM node representing the footer of the calendar.
     */
    protected abstract getFooter?(): Node;
}
/**
 * This component is a calendar view element for displaying dates.
 * Provides slots for customization through header and footer elements.
 *
 * @beta
 * @demo
 * <cxl-calendar-view value="08/06/1984"></cxl-calendar-view>
 */
export declare class CalendarView extends CalendarBase {
    protected getHeader: () => Node;
    protected getFooter: () => Node;
}
/**
 * Calendar component that lets users view events, select dates, and switch between month, day, or week views.
 *
 * @beta
 * @demo
 * <cxl-calendar value="08/06/1984"></cxl-calendar>
 */
export declare class Calendar extends CalendarBase {
    protected getHeader(): Node;
    protected getFooter: undefined;
}
