/// <amd-module name="@cxl/ui/chip.js" />
import { Component } from './component.js';
import { SurfaceColorValue } from './theme.js';
import { Size } from './core.js';
export declare abstract class BaseChip extends Component {
    /**
     * @example
     * <cxl-toolbar>
     * <cxl-chip removable size="-1">Chip</cxl-chip>
     * <cxl-chip removable size="0">Chip</cxl-chip>
     * <cxl-chip removable size="1">Chip</cxl-chip>
     * <cxl-chip removable size="2">Chip</cxl-chip>
     * <cxl-chip removable size="3">Chip</cxl-chip>
     * </cxl-toolbar>
     */
    removable: boolean;
    disabled: boolean;
    touched: boolean;
    color?: SurfaceColorValue;
    /**
     * @example
     * <cxl-toolbar>
     * <cxl-chip size="-1">Chip</cxl-chip>
     * <cxl-chip size="0">Chip</cxl-chip>
     * <cxl-chip size="1">Chip</cxl-chip>
     * <cxl-chip size="2">Chip</cxl-chip>
     * <cxl-chip size="3">Chip</cxl-chip>
     * </cxl-toolbar>
     */
    size: Size;
}
/**
 * Chips are compact elements that represent an input, attribute, or action.
 * Chips allow users to enter information, make selections, filter content, or trigger actions.
 * @example
 * <cxl-toolbar>
 * <cxl-chip>Single Chip</cxl-chip>
 * <cxl-chip color="secondary" removable>Removable</cxl-chip>
 * <cxl-chip color="primary"><cxl-avatar></cxl-avatar> Chip with Avatar</cxl-chip>
 * <cxl-chip><cxl-icon name="tag"></cxl-icon>Chip with Icon</cxl-chip>
 * </cxl-toolbar>
 */
export declare class Chip extends BaseChip {
}
/**
 * The ChipSlectable component represents a selectable chip element.
 * It's designed to be used within a ChipGroup component to create a group of selectable options with a visual chip style.
 *
 * Typical Uses:
 *
 * - Selecting a single option from a set of choices presented as chips.
 * - Filtering or categorizing items using selectable chips.
 *
 * @event change This event is triggered whenever the chip's `value` attribute changes.
 *
 * @beta
 * @see ChipGroup
 * @demo
 * <cxl-chip-group aria-label="Chip Group">
 *   <cxl-chip-selectable selected>Chip 1</cxl-chip-selectable>
 *   <cxl-chip-selectable>Chip 2</cxl-chip-selectable>
 * </cxl-chip-group>
 */
export declare class ChipSelectable extends BaseChip {
    /**
     * Controls the selected state of the chip visually.
     * Setting this to true displays the chip as selected and adds a check icon.
     */
    selected: boolean;
    /**
     * An arbitrary value associated with the chip.
     * This value can be used by your application logic to identify the selected chip.
     */
    value: unknown;
}
