/// <amd-module name="@cxl/ui/field.js" />
import { Component } from './component.js';
import { InputBase } from './input-base.js';
import { Observable } from './rx.js';
import { IconButton } from './icon-button.js';
export declare const FieldBase: (<T extends Component>($: T) => Node)[];
export declare function fieldInput<T extends Component & {
    input?: InputBase;
}>(host: T): Observable<InputBase, "none">;
export declare class FocusLine extends Component {
    focused: boolean;
    invalid: boolean;
}
/**
 * The Field component serves as a container for form input elements.
 * It allows you to customize the appearance (outlined, floating label, leading icon)
 * and layout of the field.
 *
 * @example
 * <cxl-field>
 *   <cxl-label>Form Field</cxl-label>
 *   <cxl-input></cxl-input>
 *   <cxl-field-help>Field Help Text</cxl-field-help>
 * </cxl-field>
 */
export declare class Field extends Component {
    /**
     * Sets the field to have an outlined visual style. Defaults to false.
     *
     * @example
     * <cxl-field outline>
     *   <cxl-label>Form Field</cxl-label>
     *   <cxl-input></cxl-input>
     *   <cxl-field-help>Field Help Text</cxl-field-help>
     * </cxl-field>
     */
    outline: boolean;
    /** Sets the field to have a floating label that animates when the field is focused or has a value. */
    floating: boolean;
    /** Sets the field to have an icon displayed before the input. */
    leading: boolean;
    /**
     * Sets the field to have a denser vertical spacing.
     *
     * @example
     * <cxl-field dense>
     *   <cxl-label>Form Field</cxl-label>
     *   <cxl-input></cxl-input>
     *   <cxl-field-help>Field Help Text</cxl-field-help>
     * </cxl-field>
     */
    dense: boolean;
    /**
     * A reference to the underlying input component being used within the field.
     * This allows for direct interaction with the input element.
     */
    readonly input?: InputBase;
}
/**
 * Displays helper text or error messages below input fields.
 * Place within a Field component.
 * Use the invalid property to denote invalid field states.
 *
 * @example
 * <cxl-field>
 *   <cxl-label>Field Label</cxl-label>
 *   <cxl-input touched invalid value="Input Value"></cxl-input>
 *   <cxl-field-help invalid>Field Error Text</cxl-field-help>
 * </cxl-field>
 *
 */
export declare class FieldHelp extends Component {
    /** Sets the component to an invalid style, typically indicating an error. */
    invalid: boolean;
}
/**
 * Displays the character count used within an input field relative to a defined maximum character limit.
 * This allows users to track their progress and stay within the allowed character limit.
 *
 * The FieldCounter component is designed to be used within a Field component, typically placed after the input field.
 *
 * @example
 * <cxl-field>
 *   <cxl-label>Input Label</cxl-label>
 *   <cxl-input></cxl-input>
 *   <cxl-field-counter max="100"></cxl-field-counter>
 * </cxl-field>
 */
export declare class FieldCounter extends Component {
    /**  The maximum number of characters allowed in the associated input field. */
    max: number;
    /** A reference to the underlying input component being used. */
    input?: InputBase;
}
/**
 * The FieldClear component provides a visual element to clear the value within an associated input field.
 * It appears as a close icon on the right side of the field.
 *
 * The FieldClear component is designed to be used within a Field component, typically placed after the input field.
 *
 * @beta
 * @demo
 * <cxl-field>
 *   <cxl-label>Search</cxl-label>
 *   <cxl-input></cxl-input>
 *   <cxl-field-clear></cxl-field-clear>
 * </cxl-field>
 */
export declare class FieldClear extends IconButton {
    /** The name of the icon to be displayed */
    icon: string;
    /** The width of the button in pixels */
    width: number;
}
/**
 * The Label component provides a visually distinct element to describe the expected input from the user.
 *
 * The Label component should be placed within a Field component, typically before the input field.
 */
export declare class Label extends Component {
    /**
     * A reference to the underlying input component this label is associated with.
     * This allows for automatic linking and accessibility improvements.
     */
    input?: InputBase;
}
