/// <amd-module name="@cxl/ui/form.js" />
import { Component } from './component.js';
import { Button } from './button.js';
import { SurfaceColorValue } from './theme.js';
import { InputBase } from './input-base.js';
declare module './registable.js' {
    interface RegistableMap {
        form: InputBase;
    }
}
/**
 * A button that resets the form it's associated with.
 *
 * @beta
 * @demo
 * <cxl-form>
 *   <cxl-field>
 *     <cxl-label>E-mail Address</cxl-label>
 *     <cxl-input value="Text Input Field"></cxl-input>
 *   </cxl-field>
 *   <br />
 *   <cxl-button-reset>Reset</cxl-button-reset>
 * </cxl-form>
 */
export declare class ButtonReset extends Button {
}
/**
 * A button that submits the form by triggering the submit event on the form element it's associated with.
 * Handles keyboard enter key press within the form to also trigger submission.
 * Sets a submitting state to prevent multiple submissions while processing.
 * Marks all form elements as touched to visually indicate interaction.
 *
 * @example
 * <cxl-form>
 *   <cxl-field>
 *     <cxl-label>E-mail Address</cxl-label>
 *     <cxl-input rules="required"></cxl-input>
 *   </cxl-field>
 *   <br/>
 *   <cxl-submit>Submit</cxl-submit>
 * </cxl-form>
 */
export declare class SubmitButton extends Button {
    color: SurfaceColorValue;
    readonly form?: HTMLFormElement;
    submitting: boolean;
}
/**
 * The Form component serves as a container for managing user input and form submission within
 * your application. It provides a structured way to group input elements, handle form validation,
 * and submit data to your backend.
 *
 * Typical Uses:
 * - Building login forms, registration forms, and other data collection forms.
 * - Grouping related input fields for better organization and user experience.
 * - Handling form submission logic, including validation and data processing.
 *
 * The Form component acts as a central hub for its child input elements.
 * It handles the default form submission behavior by preventing the default
 * form submission event and performing basic validation. If an invalid input exists,
 * it sets the focus to the first invalid element and prevents further form submission propagation.
 *
 * @example
 * <cxl-form>
 *   <cxl-grid>
 *   <cxl-field>
 *     <cxl-label>E-mail Address</cxl-label>
 *     <cxl-input></cxl-input>
 *   </cxl-field>
 *   <cxl-field>
 *     <cxl-label>Password</cxl-label>
 *     <cxl-password></cxl-password>
 *   </cxl-field>
 *   </cxl-grid><br/>
 *   <cxl-submit>Submit</cxl-submit>
 * </cxl-form>
 */
export declare class Form<T = Record<string, unknown>> extends Component {
    /** A read-only set containing all registered InputBase elements within the form. */
    elements: Set<InputBase>;
    protected initialValue?: T;
    /**
     * Resets the form by calling the `formResetCallback` on each child input element.
     */
    reset(): void;
    /**  Triggers the submit event on the form. */
    submit(): void;
    /** Calls the submit() method for convenience. */
    requestSubmit(): void;
    /**  Retrieves a specific input element by its name. */
    getElementByName(name: string): InputBase | undefined;
    /** Sets the touched state for all child input elements. */
    setTouched(val: boolean): void;
    /** Sets the initial form data and populates input element values. */
    setFormData(data: T): void;
    /** Retrieves an object containing the current form data. */
    getFormData(): T;
}
