/// <amd-module name="@cxl/ui/input-base.js" />
import { Component } from './component.js';
import { Observable } from './rx.js';
import { RuleKey, Validator, ValidationResult } from './validation.js';
export declare function focusProxy<T extends InputBase>(el: HTMLElement, host: T): Observable<boolean | FocusEvent | T["disabled"] | T["touched"], "none">;
export declare function invalidIfTouched<T extends InputBase>(host: T): Observable<T["invalid"], "none">;
export declare function findForm(host: HTMLElement): HTMLFormElement | undefined;
/**
 * The InputBase class serves as an abstract foundation for building custom input components.
 * It provides core functionalities for managing input state, validation, and user interaction.
 *
 * InputBase sets `static formAssociated = true`, indicating that child classes extending it
 * can participate in forms and handle form-related events.
 */
export declare abstract class InputBase extends Component {
    static formAssociated: boolean;
    /**
     * Getter and setter for the input's value. The specific data type and behavior depend on the child component.
     */
    abstract value: unknown;
    protected initialValue: unknown;
    protected internals: ElementInternals;
    /**
     * A boolean attribute specifying whether the input should receive focus automatically
     * when the component is rendered (after a slight delay).
     */
    autofocus: boolean;
    /**
     * A string or an HTMLElement representing the label for the input.
     * This can be used to associate the label with the input for accessibility purposes.
     */
    label?: HTMLElement | string;
    /**
     * A boolean style attribute reflecting the current validity state of the input. Set to true when validation fails.
     */
    invalid: boolean;
    /**
     * A boolean style attribute indicating whether the input is disabled for user interaction.
     */
    disabled: boolean;
    /**
     * A boolean style attribute to track whether the user has interacted with the input.
     */
    touched: boolean;
    /**
     * A string or an array of rules (either rule keys or validator functions) used for input validation.
     */
    rules?: string | (RuleKey | Validator)[];
    protected validMap: Record<string, ValidationResult>;
    /**
     * An object representing the current validation result of the input.
     */
    validationResult?: ValidationResult;
    name: string;
    /** Getter for the input's validity state. */
    abstract get validity(): ValidityState | null;
    /** Getter for the input's validation message */
    abstract get validationMessage(): string;
    /** Resets the input value to its initial value when the form is reset. */
    formResetCallback(): void;
    /**
     * Sets the overall validation result for the input based on the provided object.
     * This method updates the validMap and validationResult properties.
     */
    setValidity(result: ValidationResult): ValidationResult | undefined;
    /**
     * Sets a custom validation message for the input. This updates the invalid and
     * validationMessage properties and triggers an 'invalid' event if the message changes.
     */
    setCustomValidity(msg: string): void;
    protected abstract applyValidity(invalid: boolean, msg?: string): void;
}
/**
 * The CustomInputBase class extends the InputBase class, providing a foundation
 * for building custom input components that don't rely on standard HTML input elements.
 *
 * The validity and validationMessage getters delegate to the `internals` object
 * (provided by the browser's attachInternals API) to retrieve the standard validity
 * state and message whenever available.
 * This allows leveraging browser validation features for common input patterns.
 */
export declare abstract class CustomInputBase extends InputBase {
    get validity(): ValidityState | null;
    get validationMessage(): string;
    protected formDisabledCallback(disabled: boolean): void;
    applyValidity(invalid: boolean, msg?: string): void;
}
/**
 * The ProxiedInputBase class extends the CustomInputBase class, offering a foundation for
 * custom input components that utilize Shadow DOM for encapsulation and leverage a proxied
 * HTML input element for core input functionality.
 */
export declare abstract class ProxiedInputBase extends InputBase {
    /**
     * An abstract property requiring child classes to define an HTMLInputElement that
     * serves as the internal input element within the Shadow DOM.
     */
    abstract inputEl: HTMLInputElement;
    constructor();
    applyValidity(invalid: boolean, msg?: string): void;
    /**
     * Delegates the focus call to the `inputEl`, ensuring focus is set on the internal input element.
     */
    focus(): void;
    get validationMessage(): string;
    get validity(): ValidityState | null;
}
