/// <amd-module name="@cxl/ui/panel.js" />
import { Component } from './component.js';
declare module './registable.js' {
    interface RegistableMap {
        panel: Panel;
    }
}
declare module './dom.js' {
    interface CustomEventMap {
        'panel.visible': boolean;
    }
}
/**
 * The PanelGroup component manages a collection of Panel components.
 * It provides an accordion-like functionality where only one panel can be visible at a time.
 *
 * Each Panel should have a child element with the slot="header" attribute to define the panel's header content.
 * The remaining content within the Panel will be considered the panel's body.
 *
 * @example
 * <cxl-panel-group>
 *   <cxl-panel>
 *     <div slot="header">Panel Header 1</div>
 *     Panel 1
 *   </cxl-panel>
 *   <cxl-panel>
 *     <div slot="header">Panel Header 2</div>
 *     Panel 2
 *   </cxl-panel>
 *   <cxl-panel>
 *     <div slot="header">Panel Header 3</div>
 *     Panel 3
 *   </cxl-panel>
 * </cxl-panel-group>
 */
export declare class PanelGroup extends Component {
    /**
     * A Set containing references to all child Panel components within the group.
     */
    panels: Set<Panel>;
}
/**
 * The PanelHeader component is an element designed specifically for use within the PanelGroup component.
 * It represents the expandable header of a Panel.
 *
 * The `ariaExpanded` attribute is dynamically set based on the opened property to indicate the panel's expansion state to screen readers.
 *
 */
export declare class PanelHeader extends Component {
    /**
     * A boolean value indicating whether the associated panel is currently expanded (true) or collapsed (false).
     */
    opened: boolean;
    /**
     * A boolean value indicating whether the header should be disabled (not clickable).
     */
    disabled: boolean;
    touched: boolean;
}
/**
 * The PanelBody component is designed for use within the Panel component.
 * It represents the expandable content area of a panel.
 *
 * Manages the visibility and animation of the content based on the panel's open/closed state.
 */
export declare class PanelBody extends Component {
    /**
     * A boolean value indicating whether the associated panel is currently expanded (true) and
     * its content is visible, or collapsed (false) and its content is hidden.
     */
    opened: boolean;
}
/**
 * The Panel component represents an individual panel with a header and collapsible content area.
 * The component Manages the visibility and animation of the content based on the panel's
 * open/closed state and communicates visibility changes to the PanelGroup component.
 *
 * @see PanelGroup
 * @demo
 * <cxl-panel-group>
 *   <cxl-panel>
 *     <div slot="header">Panel Header 1</div>
 *     Panel 1
 *   </cxl-panel>
 *   <cxl-panel>
 *     <div slot="header">Panel Header 2</div>
 *     Panel 2
 *   </cxl-panel>
 */
export declare class Panel extends Component {
    /**
     * A boolean value indicating whether the panel is currently expanded (true) and
     * its content is visible, or collapsed (false) and its content is hidden.
     */
    opened: boolean;
}
