/// <amd-module name="@cxl/ui/rx.js" />
type ObservableError = unknown;
type NextFunction<T> = (val: T) => void;
type ErrorFunction = (err: ObservableError) => void;
type CompleteFunction = () => void;
type UnsubscribeFunction = () => void;
type SubscribeFunction<T> = (subscription: Subscriber<T>) => UnsubscribeFunction | void | Promise<void>;
type Merge<T> = T extends Observable<infer U> ? U : never;
type ObservableT<T> = T extends Observable<infer U> ? U : never;
type PickObservable<T> = {
    [P in keyof T]: T[P] extends Observable<unknown> ? ObservableT<T[P]> : never;
};
export type Operator<T, T2 = T> = (observable: Observable<T>) => Observable<T2>;
export interface Observer<T> {
    next?: NextFunction<T>;
    error?: ErrorFunction;
    complete?: CompleteFunction;
}
export interface Subscribable<T> {
    subscribe(observer: Observer<T>): Subscription;
}
export declare const observableSymbol = "@@observable";
export interface InteropObservable<T> {
    [observableSymbol]: () => Subscribable<T>;
}
type NextObserver<T> = NextFunction<T> | Observer<T> | undefined;
export interface Subscription {
    unsubscribe(): void;
}
export declare class Subscriber<T> {
    private observer;
    private onUnsubscribe;
    private teardown?;
    closed: boolean;
    constructor(observer: Observer<T>, subscribe?: SubscribeFunction<T>, fwd?: (subscriber: Subscription) => void);
    setTeardown(teardown: () => void): void;
    next(val: T): void;
    error(e: ObservableError): void;
    complete(): void;
    unsubscribe(): void;
}
/**
 * Used to stitch together functional operators into a chain.
 */
export declare function pipe<T, A, B>(a: Operator<T, A>, b: Operator<A, B>): Operator<T, B>;
export declare function pipe<T, A, B, C>(a: Operator<T, A>, b: Operator<A, B>, c: Operator<B, C>): Operator<T, C>;
export declare function pipe<T, A, B, C, D>(a: Operator<T, A>, b: Operator<A, B>, c: Operator<B, C>, d: Operator<C, D>): Operator<T, D>;
export declare function pipe<T, A, B, C, D, E>(a: Operator<T, A>, b: Operator<A, B>, c: Operator<B, C>, d: Operator<C, D>, e: Operator<D, E>): Operator<T, E>;
/**
 * A representation of any set of values over any amount of time.
 */
export declare class Observable<T, P = 'none'> {
    protected __subscribe: SubscribeFunction<T>;
    [observableSymbol](): this;
    constructor(__subscribe: SubscribeFunction<T>);
    then<E, R>(resolve: (val: P extends 'emit1' ? T : T | undefined) => R, reject?: (e: E) => R): Promise<R>;
    pipe<A>(a: Operator<T, A>): Observable<A>;
    pipe<A, B>(a: Operator<T, A>, b: Operator<A, B>): Observable<B>;
    pipe<A, B, C>(a: Operator<T, A>, b: Operator<A, B>, c: Operator<B, C>): Observable<C>;
    pipe<A, B, C, D>(a: Operator<T, A>, b: Operator<A, B>, c: Operator<B, C>, d: Operator<C, D>): Observable<D>;
    pipe<A, B, C, D, E>(a: Operator<T, A>, b: Operator<A, B>, c: Operator<B, C>, d: Operator<C, D>, e: Operator<D, E>): Observable<E>;
    /**
     * Invokes an execution of an Observable and registers Observer handlers for notifications it will emit.
     */
    subscribe(next?: NextObserver<T>, fwd?: (subs: Subscription) => void): Subscription;
}
/**
 * A Subject is an Observable that allows values to be
 * multicasted to many Observers.
 */
export declare class Subject<T, ErrorT = unknown> extends Observable<T> {
    protected observers: Set<Subscriber<T>>;
    protected onSubscribe(subscriber: Subscriber<T>): UnsubscribeFunction;
    protected isStopped: boolean;
    constructor();
    next(a: T): void;
    error(e: ErrorT): void;
    complete(): void;
}
/**
 * A subject that guarantees all subscribers receive the same values in the order they were emitted.
 */
export declare class OrderedSubject<T> extends Subject<T> {
    private queue;
    private emitting;
    next(a: T): void;
}
/**
 * A variant of Subject that requires an initial value and emits its current value whenever it is subscribed to.
 * @see be
 */
export declare class BehaviorSubject<T> extends Subject<T> {
    private currentValue;
    constructor(currentValue: T);
    get value(): T;
    protected onSubscribe(subscription: Subscriber<T>): UnsubscribeFunction;
    next(val: T): void;
}
/**
 * A variant of Subject that "replays" or emits old values to new subscribers.
 * It buffers a set number of values and will emit those values immediately to any
 * new subscribers in addition to emitting new values to existing subscribers.
 */
export declare class ReplaySubject<T, ErrorT = unknown> extends Subject<T, ErrorT> {
    readonly bufferSize: number;
    private buffer;
    private hasError;
    private lastError?;
    constructor(bufferSize?: number);
    protected onSubscribe(subscriber: Subscriber<T>): () => boolean;
    error(val: ErrorT): void;
    next(val: T): void;
}
declare const Undefined: {};
/**
 * A Reference is a behavior subject that does not require an initial value.
 */
export declare class Reference<T> extends Subject<T> {
    protected $value: T | typeof Undefined;
    get hasValue(): boolean;
    get value(): T;
    protected onSubscribe(subscription: Subscriber<T>): UnsubscribeFunction;
    next(val: T): void;
}
type ConcatResult<R extends Observable<unknown>[]> = R extends (infer U)[] ? Observable<Merge<U>> : never;
/**
 * Creates an output Observable which sequentially emits all values from given Observable and then moves on to the next.
 */
export declare function concat<R extends Observable<unknown>[]>(...observables: R): ConcatResult<R>;
/**
 * Creates an Observable that, on subscribe, calls an Observable factory to make an Observable for each new Observer.
 */
export declare function defer<T>(fn: () => Subscribable<T>): Observable<T, "none">;
export declare function isInterop<T>(obs: object): obs is InteropObservable<T>;
export declare function fromArray<T>(input: Array<T>): Observable<T>;
export declare function fromPromise<T>(input: Promise<T>): Observable<T>;
export declare function fromAsync<T>(input: () => Promise<T>): Observable<T>;
/**
 * Creates an Observable from an Array, an array-like object, a Promise, an iterable object, or an Observable-like object.
 */
export declare function from<T>(input: Array<T> | Promise<T> | Observable<T> | InteropObservable<T>): Observable<T>;
/**
 * Converts the arguments to an observable sequence.
 */
export declare function of<T>(...values: T[]): Observable<T>;
/**
 * Generates a promise from an observable, the promise will resolve when the observable completes.
 */
export declare function toPromise<T, P>(observable: Observable<T, P>): Promise<P extends 'emit1' ? T : T | undefined>;
export declare class EmptyError extends Error {
    message: string;
}
export declare function firstValueFrom<T>(observable: Observable<T>): Promise<T>;
export declare function operatorNext<T, T2 = T>(fn: (subs: Subscriber<T2>) => NextFunction<T>, unsubscribe?: () => void): (source: Observable<T>) => Observable<T2, "none">;
export declare function operator<T, T2 = T>(fn: (subs: Subscriber<T2>, source: Observable<T>) => Observer<T> & {
    next: NextFunction<T>;
    unsubscribe?: UnsubscribeFunction;
}): Operator<T, T2>;
/**
 * Applies a given project function to each value emitted by the source Observable, and emits the resulting values as an Observable.
 */
export declare function map<T, T2>(mapFn: (val: T) => T2): (source: Observable<T, "none">) => Observable<T2, "none">;
/**
 * Applies an accumulator function over the source Observable, and returns the accumulated result when the source completes, given an optional seed value.
 */
export declare function debounceFunction<F extends (...args: any) => any>(fn: F, delay?: number): ((...args: Parameters<F>) => void) & {
    cancel(): void;
};
export declare function interval(period: number): Observable<void, "none">;
export declare function timer(delay: number): Observable<void, "none">;
/**
 * Emits a value from the source Observable only after a particular time span has passed without another source emission.
 */
export declare function debounceTime<T>(time?: number, useTimer?: typeof timer): Operator<T, T>;
/**
 * Projects each source value to an Observable which is merged in the output Observable,
 * emitting values only from the most recently projected Observable.
 */
export declare function switchMap<T, T2>(project: (val: T) => Observable<T2>): (source: Observable<T>) => Observable<T2, "none">;
/**
 * Projects each source value to an Observable which is merged in the output Observable.
 */
export declare function mergeMap<T, T2>(project: (val: T) => Observable<T2>): (source: Observable<T>) => Observable<T2, "none">;
/**
 * Projects each source value to an Observable which is merged in the output Observable
 * only if the previous projected Observable has completed.
 */
/**
 * Filter items emitted by the source Observable.
 *
 * @see distinctUntilChanged
 */
export declare function filter<T>(fn: (val: T) => boolean): Operator<T, T>;
/**
 * Emits only the first count values emitted by the source Observable.
 */
export declare function take<T>(howMany: number): (source: Observable<T, "none">) => Observable<T, "none">;
/**
 * Emits values while fn result is truthy.
 */
export declare function takeWhile<T>(fn: (val: T) => boolean): (source: Observable<T, "none">) => Observable<T, "none">;
/**
 * Emits only the first value emitted by the source Observable.
 * Delivers an EmptyError to the Observer's error callback if the Observable completes before any next notification was sent
 */
export declare function first<T>(): Operator<T, T>;
/**
 * Perform a side effect for every emission on the source Observable,
 * but return an Observable that is identical to the source.
 */
export declare function tap<T>(fn: (val: T) => void): Operator<T, T>;
/**
 * Catches errors on the observable.
 *
 * @param selector A function that takes as arguments the error `err`,  and `source`, which
 *  is the source observable. The observable
 *  returned will be used to continue the observable chain.
 *
 */
export declare function catchError<T, O extends T | never>(selector: (err: unknown, source: Observable<T>) => Observable<O> | void): Operator<T, T>;
/**
 * Returns an Observable that emits all items emitted by the source Observable
 * that are distinct by comparison from the previous item.
 */
export declare function distinctUntilChanged<T>(): Operator<T, T>;
export declare function select<StateT, K extends keyof StateT>(key: K): (source: Observable<StateT, "none">) => Observable<StateT[K], "none">;
export declare function share<T>(): Operator<T, T>;
/**
 * Returns an observable that shares a single subscription to the underlying sequence containing only the last notification.
 */
export declare function publishLast<T>(): Operator<T, T>;
type MergeResult<R extends Observable<unknown>[]> = R extends (infer U)[] ? Observable<Merge<U>> : never;
/**
 * Creates an output Observable which concurrently emits all values from every given input Observable.
 */
export declare function merge<R extends Observable<unknown>[]>(...observables: R): MergeResult<R>;
/**
 * Combines multiple Observables to create an Observable whose values are calculated from the values, in order, of each of its input Observables.
 */
export declare function zip<T extends Observable<unknown>[]>(...observables: T): Observable<PickObservable<T>>;
/**
 * Combines multiple Observables to create an Observable whose values are calculated from the
 * latest values of each of its input Observables.
 */
export declare function combineLatest<T extends Observable<unknown>[]>(...observables: T): Observable<PickObservable<T>>;
/**
 * Returns an Observable that mirrors the source Observable, but will call a
 * specified function when the source terminates on complete or error.
 */
export declare function finalize<T>(unsubscribe: () => void): Operator<T, T>;
export declare function ignoreElements(): Operator<never, never>;
/**
 * Creates an Observable that emits no items to the Observer and immediately emits an error notification.
 */
export declare function throwError(error: unknown): Observable<never, "none">;
/**
 * An observable that completes on subscription.
 */
export declare const EMPTY: Observable<never, "none">;
/**
 * Creates a new Behavior Subject.
 */
export declare function be<T>(initialValue: T): BehaviorSubject<T>;
/**
 * Creates a new Observable
 */
export declare function observable<T>(subscribe: SubscribeFunction<T>): Observable<T, "none">;
/**
 * Creates a new Subject
 */
export declare function subject<T>(): Subject<T, unknown>;
/**
 * Creates a new Reference object. A reference is a Behavior Subject that does not require an initial value.
 */
export declare function ref<T>(): Reference<T>;
export declare const operators: {
    readonly catchError: typeof catchError;
    readonly debounceTime: typeof debounceTime;
    readonly distinctUntilChanged: typeof distinctUntilChanged;
    readonly filter: typeof filter;
    readonly finalize: typeof finalize;
    readonly first: typeof first;
    readonly ignoreElements: typeof ignoreElements;
    readonly map: typeof map;
    readonly mergeMap: typeof mergeMap;
    readonly publishLast: typeof publishLast;
    readonly select: typeof select;
    readonly share: typeof share;
    readonly switchMap: typeof switchMap;
    readonly take: typeof take;
    readonly takeWhile: typeof takeWhile;
    readonly tap: typeof tap;
};
export interface Observable<T> {
    catchError<T2 extends T | never>(selector: (err: unknown, source: Observable<T>) => Observable<T2> | void): Observable<T>;
    debounceTime(time?: number, timer?: (delay: number) => Observable<void>): Observable<T>;
    distinctUntilChanged(): Observable<T>;
    filter<T2 = T>(fn: (val: T) => boolean): Observable<T2>;
    finalize(fn: () => void): Observable<T>;
    first(): Observable<T>;
    map<T2>(mapFn: (val: T) => T2): Observable<T2>;
    mergeMap<T2>(project: (val: T) => Observable<T2>): Observable<T2>;
    publishLast(): Observable<T>;
    select<K extends keyof T>(key: K): Observable<T[K]>;
    share(): Observable<T>;
    switchMap<T2>(project: (val: T) => Observable<T2>): Observable<T2>;
    take(howMany: number): Observable<T>;
    takeWhile(fn: (val: T) => boolean): Observable<T>;
    tap(tapFn: (val: T) => void): Observable<T>;
    ignoreElements(): Observable<never>;
}
export {};
