/// <amd-module name="@cxl/ui/scroll.js" />
import { Observable } from './rx.js';
export interface VirtualScrollBaseOptions {
    /**
     * Number of total records
     */
    dataLength: number;
    /**
     * Scrolling axis
     */
    axis?: 'y' | 'x';
    /**
     * Callback function. Called each time for every item that needs to be rendered.
     */
    render: (index: number, order: number) => HTMLElement;
    /**
     * Signals the renderer to recalculate item dimensions.
     */
    refresh?: Observable<void | {
        dataLength: number;
    }>;
}
export interface VirtualScrollRenderOptions extends VirtualScrollBaseOptions {
    /**
     * Scrollable element used to display the scroll bar.
     */
    scrollElement: HTMLElement;
}
export interface VirtualScrollOptions extends VirtualScrollBaseOptions {
    /**
     * Element where items will be rendered.
     */
    host: HTMLElement;
    /**
     * Scrollable element used to display the scroll bar. Defaults to the parent element of `host`
     */
    scrollElement?: HTMLElement;
}
export interface InfiniteScrollOptions extends VirtualScrollOptions {
    /**
     * This mandatory function is called whenever the user reaches the end of the currently rendered data.
     * It should fetch more data and return the new total data length.
     * The infiniteScroll function will then trigger a refresh to update the rendered content.
     */
    loadMore: (index: number) => number;
}
export interface VirtualScrollEvent {
    /**
     * Start index of items rendered.
     */
    start: number;
    /**
     * End index of items rendered.
     */
    end: number;
    /**
     * Calculated size in pixels of all visible items
     */
    size: number;
    /**
     * Calculated size in pixels of all items.
     */
    totalSize: number;
    /**
     * Number of items rendered
     */
    count: number;
    /**
     * Offset used to position the item container once it reaches the end of the scrolling window
     */
    offset: number;
}
/**
 * Provides basic vertical and horizontal virtual scroll functionality.
 * @beta
 */
export declare function virtualScrollRender(options: VirtualScrollRenderOptions): Observable<VirtualScrollEvent>;
/**
 * Virtual scrolling is a technique used to optimize the rendering of large amounts of data.
 * It allows users to scroll through a list of items without having to load the entire list into memory
 * or render it on the page at once. Instead, only the visible portion of the list is rendered,
 * and as the user scrolls, additional items are loaded and rendered as needed.
 *
 * @beta
 */
export declare function virtualScroll(options: VirtualScrollOptions): Observable<VirtualScrollEvent, "none">;
/**
 * This function provides a mechanism for infinite scrolling, which is a technique used to progressively
 * load more data as the user scrolls down the list.
 * It builds upon the virtualScroll function to efficiently render large datasets.
 *
 * @beta
 * @returns An observable that emits events containing information about the rendered data whenever the viewport or data changes.
 */
export declare function infiniteScroll(options: InfiniteScrollOptions): Observable<VirtualScrollEvent, "none">;
