/// <amd-module name="@cxl/ui/select.js" />
import { Component } from './component.js';
import { CustomInputBase, InputBase } from './input-base.js';
import { PopupBase, PopupPosition } from './popup.js';
import type { Option } from './option.js';
export declare class SelectOption extends Component {
}
/**
 * The SelectMenuBase class serves as a foundation for building select menu components.
 * It provides the core functionalities for managing a dropdown menu associated with a user input element.
 */
export declare abstract class SelectMenuBase extends PopupBase {
    readonly selected?: unknown;
    readonly options: Set<Option>;
    protected readonly acceptKeys: string[];
    protected readonly value$: import("@cxl/ui/rx.js").Reference<unknown>;
    protected readonly positionStyle: HTMLStyleElement;
    /** The input element associated with the select menu. */
    input?: InputBase;
    /** Implemented by subclasses to set the focused option within the menu. */
    abstract setFocusedOption(option?: Option): void;
    /** Implemented by subclasses to handle selecting an option and updating the selected value. */
    protected abstract setSelected(option?: Option): void;
    focusedOption?: Option;
    protected setInputLabel?(input: SelectInput): void;
    /** Sets the value of the associated input element. */
    protected setInputValue(input: InputBase, value: unknown): void;
    /** Positions the menu dropdown relative to the input element. */
    protected positionMenu(input: HTMLElement): void;
}
/**
 * The SelectMenu component implements a fully functional select menu, building upon the foundation provided by
 * SelectMenuBase. It manages options, user selection, and interaction with a target input element.
 */
export declare class SelectMenu extends SelectMenuBase {
    /** The currently selected option. */
    readonly selected?: Option;
    /** Set of available options for the menu. */
    readonly options: Set<Option>;
    /** The component used to render each option within the menu. */
    readonly optionView: typeof SelectOption;
    /**  Sets the focused option in the menu. */
    setFocusedOption(option?: Option): void;
    /** Sets the label text of the associated input element based on the selected option. */
    protected setInputLabel(input: SelectInput): void;
    /** Sets the selected option and updates the target input element. */
    protected setSelected(option?: Option): void;
    /** Positions the menu based on the target input element. */
    protected positionMenu(input: HTMLElement): void;
}
/**
 * This component creates a styled input element that functions as the trigger for a cxl-select-menu dropdown.
 */
export declare class SelectInput extends CustomInputBase {
    /** The current value of the input element. */
    value: unknown;
    /**  Controls the visibility of the associated cxl-select-menu (true = open, false = closed). */
    opened: boolean;
    /** References the cxl-select-menu component it controls. */
    target?: SelectMenuBase;
    /**
     * Defines the positioning strategy for the associated SelectMenu dropdown.
     * Can be a predefined position ('none', 'top', 'bottom', etc.) or a custom function that
     * receives the input element and performs custom positioning logic.
     */
    position: PopupPosition | ((el: HTMLElement) => void);
    handleFocus: boolean;
}
/**
 * This component creates a fully functional select box with a dropdown menu for single option selection.
 *
 * @example
 * <cxl-field>
 *   <cxl-label>Select Box</cxl-label>
 *   <cxl-select value="2">
 *     <cxl-option value="1">Option 1</cxl-option>
 *     <cxl-option value="2">Option 2</cxl-option>
 *     <cxl-option value="3">Option 3</cxl-option>
 *   </cxl-select>
 * </cxl-field>
 *
 * @see MultiSelect
 */
export declare class SelectBox extends SelectMenu {
    /** Controls the disabled state of the select box (true = disabled, false = enabled). */
    disabled: boolean;
    /** The currently selected value of the select box. */
    value: unknown;
    /** Sets the name attribute of the underlying input element for form submission purposes. */
    name: string;
    /** Provides direct access to the underlying SelectInput component. */
    readonly input: SelectInput;
}
