/// <amd-module name="@cxl/ui/slider.js" />
import { Component } from './component.js';
import { CustomInputBase } from './input-base.js';
/**
 * Represents a horizontal slider component for UI elements.
 *
 * Contains a background bar and slots for cxl-slider-knob elements.
 *
 * @beta
 * @demo
 * <cxl-slider-bar>
 *   <cxl-slider-knob aria-label="knob 1" value="0.5"></cxl-slider-knob>
 *   <cxl-slider-knob aria-label="knob 2" value="1"></cxl-slider-knob>
 * </cxl-slider-bar>
 */
export declare class SliderBar extends Component {
    /** Indicates whether the slider is in an invalid state */
    invalid: boolean;
}
/**
 * Represents a draggable knob element for use within a cxl-slider-bar component.
 * Provides visual feedback and allows user interaction to set a numerical value within the slider.
 *
 * @see SliderBar
 * @beta
 * @demo
 * <cxl-slider-bar>
 *   <cxl-slider-knob aria-label="knob 0" value="0"></cxl-slider-knob>
 *   <cxl-slider-knob aria-label="knob 1" value="0.5"></cxl-slider-knob>
 *   <cxl-slider-knob aria-label="knob 2" value="1"></cxl-slider-knob>
 * </cxl-slider-bar>
 */
export declare class SliderKnob extends CustomInputBase {
    /** The current value of the knob, between 0 and 1. */
    value: number;
    /** The amount by which the value changes when using the keyboard arrows or dragging the knob. */
    step: number;
}
/**
 * The SliderTooltip component displays the slider's current value dynamically as the user interacts
 * with the slider (dragging, hovering, focusing), enhancing usability and accessibility.
 *
 * @see SliderBar
 * @since 4.0.3
 * @beta
 *
 * @demo
<cxl-c pad="32" style="overflow:hidden">
    <cxl-slider-bar>
        <cxl-slider-knob aria-label="knob 0" value="0">
            <cxl-slider-tooltip id="tooltip"></cxl-slider-tooltip>
        </cxl-slider-knob>
    </cxl-slider-bar>
</cxl-c>
<script>
tooltip.format = v => Math.round(v*100);
</script>
 *
 */
export declare class SliderTooltip extends Component {
    /**
     * A function that takes a number and formats it as a string.
     */
    format?: (n: number) => string;
}
/**
 * Represents a horizontal line element displayed within a cxl-slider-bar component.
 * Visually indicates the minimum and maximum range of the slider.
 *
 * @see SliderBar
 */
export declare class SliderLine extends Component {
    /** The minimum value the slider can represent */
    min: number;
    /** The maximum value the slider can represent. */
    max: number;
}
/**
 * Represents a dual-knob slider component for selecting a range of numerical values.
 * Provides a visual track and two interactive knobs for setting the minimum and maximum values.
 *
 * @example
 * <cxl-slider-range></cxl-slider-range>
 */
export declare class SliderRange extends CustomInputBase {
    /**
     * The amount by which each knob's value changes when using the keyboard arrows or dragging.
     */
    step: number;
    /**
     * An array containing two numbers representing the current minimum and maximum values of the range.
     */
    value: [number, number];
    /** Sets focus to the first slider knob if the component is not disabled. */
    focus(): void;
}
/**
 * Sliders allow users to make selections from a range of values.
 * Represents a single-knob slider component for selecting a numerical value from a range of 0 to 1.
 * Provides a visual track, a draggable knob, and keyboard controls for user interaction.
 *
 * @example
 * <cxl-slider aria-label="slider with default value"></cxl-slider>
 * <cxl-slider value="0.5" aria-label="slider"></cxl-slider>
 */
export declare class Slider extends CustomInputBase {
    /**
     * The amount by which the value changes when using the keyboard arrows or dragging the knob.
     */
    step: number;
    /** The current value of the slider, between 0 and 1. */
    value: number;
}
