/// <amd-module name="@cxl/ui/snackbar.js" />
import { Component } from './component.js';
import { SurfaceColorValue } from './theme.js';
import { Alert } from './alert.js';
export interface SnackbarOptions {
    delay?: number;
    color?: SurfaceColorValue;
    dense?: boolean;
    content: string | Node;
    container?: SnackbarContainer;
}
/**
 * This component creates a dismissible snackbar notification that appears briefly at the bottom of the screen.
 *
 * @example
 * <cxl-snackbar>Snackbar Content</cxl-snackbar>
 */
export declare class Snackbar extends Alert {
    /** Defines the duration (in milliseconds) for which the snackbar will be displayed before automatically hiding. Defaults to 4000ms (4 seconds). */
    delay: number;
}
/**
 * The SnackbarContainer acts as a container component that orchestrates the display of Snackbar elements.
 * It maintains a queue and ensures only one notification is visible at a time.
 */
export declare class SnackbarContainer extends Component {
    /**
     * An internal queue that stores references to Snackbar components and their respective resolution functions.
     */
    queue: [Snackbar, () => void][];
    /**
     * Triggers the display of the next snackbar in the queue, handling animation, removal, and queue advancement.
     */
    private notifyNext;
    /**
     * Public method to enqueue a new Snackbar component for display.
     * It returns a promise that resolves when the snackbar is removed from the DOM.
     */
    notify(snackbar: Snackbar): Promise<void>;
}
/**
 * If a container is not specified by using the _setSnackbarContainer_ function, _notify_ will create a new container and store it in this variable.
 */
export declare let snackbarContainer: SnackbarContainer | undefined;
/**
 * Simplifies the process of creating and displaying snackbar notifications.
 * @param options Defines the configuration for the snackbar notification.
 * If a string is provided, it's treated as the snackbar content.
 * Otherwise, a SnackbarOptions object can be used for more detailed configuration.
 * SnackbarOptions (implicit):
 * - content (string): The message content to be displayed in the snackbar.
 * - delay (number): The duration (in milliseconds) for which the snackbar will be displayed before automatically hiding. Defaults to the value set on the Snackbar component (usually 4 seconds).
 * - color (string): The color theme for the snackbar
 * - dense (boolean): Controls the vertical spacing within the snackbar
 * - container (SnackbarContainer): An optional reference to a specific SnackbarContainer component for managing the queue. If not provided, a default container is created and attached to the document body.
 */
export declare function notify(options: string | SnackbarOptions): Promise<void>;
export declare function setSnackbarContainer(bar: SnackbarContainer): void;
