/// <amd-module name="@cxl/ui/toggle.js" />
import { Component } from './component.js';
import { Observable } from './rx.js';
import { AnimationKey } from './theme.js';
export interface ToggleTarget extends HTMLElement {
    visible?: boolean;
}
export interface ToggleEvent<T extends HTMLElement> {
    target: T;
    opened: boolean;
    animation?: Animation;
}
export interface ToggleComponent<T extends HTMLElement> extends Component {
    opened: boolean;
    target?: string | T;
}
export declare function toggleBehavior<T extends ToggleTarget>(trigger: Element, getTarget: () => T | undefined, isVisible: () => boolean, opened: Observable<boolean>): Observable<{
    target: T;
    opened: boolean;
}, "none">;
/**
 * This function provides a reusable behavior for toggling the visibility of a target element based on user interaction with another element (the trigger).
 */
export declare function toggleComponent<T extends ToggleTarget>(host: ToggleComponent<T>): Observable<{
    target: T;
    opened: boolean;
}, "none">;
/**
 * The Toggle component provides a way to control the visibility of another element through user interaction (typically a click) on the toggle element.
 *
 * @beta
 * @demo
 * <cxl-toggle target="popup"><cxl-button>Toggle</cxl-button></cxl-toggle>
 * <cxl-popup aria-label="target popup" id="popup">Popup Content</cxl-popup>
 */
export declare class Toggle extends Component {
    /**
     * This attribute controls the initial visibility state of the target element. Set it to true to show the target element initially.
     */
    opened: boolean;
    /**
     * This attribute specifies the ID or a reference to the element that should be shown/hidden when the toggle is interacted with.
     */
    target?: string | ToggleTarget;
}
/**
 * The ToggleBase class provides a base implementation for components that manage a show/hide
 * state and potentially animations for transitioning between states.
 */
declare abstract class ToggleBase extends Component {
    /**
     * This property controls the visibility state of the toggle target element. Setting it to true shows the target, while false hides it.
     */
    opened: boolean;
    /**
     * his attribute allows you to specify the name of an animation that should be played when the toggle target element becomes visible.
     */
    animationin?: AnimationKey;
    /**
     * Similar to animationin, this attribute specifies the name of an animation to play when the toggle target element becomes hidden.
     */
    animationout?: AnimationKey;
}
/**
 * The TogglePanel component provides a mechanism to show or hide a designated content area (target)
 * in response to user interaction with a trigger element.
 *
 * @beta
 *
 * @demo
 * <cxl-toggle-panel opened>
 *   <cxl-button>Toggle</cxl-button>
 *   <cxl-icon alt="toggle target" slot="target" style="margin-left:24px" name="done"></cxl-icon>
 * </cxl-toggle-panel>
 */
export declare class TogglePanel extends ToggleBase {
}
/**
 * The ToggleSwitch component provides a visual representation of a toggle state (on or off)
 * and allows users to change it through interaction with a trigger element.
 *
 * The component provides two named slots, "off" and "on," to display different content based on the toggle state.
 *
 * @demo
<cxl-toggle-switch>
  <cxl-button>Toggle Switch</cxl-button>
  <br /><br />
  <div slot="off">Switch is off</div>
  <div slot="on">Switch is on</div>
</cxl-toggle-switch>
 */
export declare class ToggleSwitch extends ToggleBase {
}
export {};
