/// <amd-module name="@cxl/ui/rx.js" />
declare module "@cxl/ui/rx.js" {
    type ObservableError = unknown;
    type NextFunction<T> = (val: T) => void;
    type ErrorFunction = (err: ObservableError) => void;
    type CompleteFunction = () => void;
    type UnsubscribeFunction = () => void;
    type SubscribeFunction<T> = (subscription: Subscriber<T>) => UnsubscribeFunction | void | Promise<void>;
    type Merge<T> = T extends Observable<infer U> ? U : never;
    type ObservableT<T> = T extends Observable<infer U> ? U : never;
    type PickObservable<T> = {
        [P in keyof T]: T[P] extends Observable<unknown> ? ObservableT<T[P]> : never;
    };
    export type Operator<T, T2 = T> = (observable: Observable<T>) => Observable<T2>;
    export interface Observer<T> {
        next?: NextFunction<T>;
        error?: ErrorFunction;
        complete?: CompleteFunction;
    }
    export interface Subscribable<T> {
        subscribe(observer: Observer<T>): Subscription;
    }
    export const observableSymbol = "@@observable";
    export interface InteropObservable<T> {
        [observableSymbol]: () => Subscribable<T>;
    }
    type NextObserver<T> = NextFunction<T> | Observer<T> | undefined;
    export interface Subscription {
        unsubscribe(): void;
    }
    export class Subscriber<T> {
        private observer;
        private onUnsubscribe;
        private teardown?;
        closed: boolean;
        constructor(observer: Observer<T>, subscribe?: SubscribeFunction<T>, fwd?: (subscriber: Subscription) => void);
        setTeardown(teardown: () => void): void;
        next(val: T): void;
        error(e: ObservableError): void;
        complete(): void;
        unsubscribe(): void;
    }
    /**
     * Used to stitch together functional operators into a chain.
     */
    export function pipe<T, A, B>(a: Operator<T, A>, b: Operator<A, B>): Operator<T, B>;
    export function pipe<T, A, B, C>(a: Operator<T, A>, b: Operator<A, B>, c: Operator<B, C>): Operator<T, C>;
    export function pipe<T, A, B, C, D>(a: Operator<T, A>, b: Operator<A, B>, c: Operator<B, C>, d: Operator<C, D>): Operator<T, D>;
    export function pipe<T, A, B, C, D, E>(a: Operator<T, A>, b: Operator<A, B>, c: Operator<B, C>, d: Operator<C, D>, e: Operator<D, E>): Operator<T, E>;
    /**
     * A representation of any set of values over any amount of time.
     */
    export class Observable<T, P = 'none'> {
        protected __subscribe: SubscribeFunction<T>;
        [observableSymbol](): this;
        constructor(__subscribe: SubscribeFunction<T>);
        then<E, R>(resolve: (val: P extends 'emit1' ? T : T | undefined) => R, reject?: (e: E) => R): Promise<R>;
        pipe<A>(a: Operator<T, A>): Observable<A>;
        pipe<A, B>(a: Operator<T, A>, b: Operator<A, B>): Observable<B>;
        pipe<A, B, C>(a: Operator<T, A>, b: Operator<A, B>, c: Operator<B, C>): Observable<C>;
        pipe<A, B, C, D>(a: Operator<T, A>, b: Operator<A, B>, c: Operator<B, C>, d: Operator<C, D>): Observable<D>;
        pipe<A, B, C, D, E>(a: Operator<T, A>, b: Operator<A, B>, c: Operator<B, C>, d: Operator<C, D>, e: Operator<D, E>): Observable<E>;
        /**
         * Invokes an execution of an Observable and registers Observer handlers for notifications it will emit.
         */
        subscribe(next?: NextObserver<T>, fwd?: (subs: Subscription) => void): Subscription;
    }
    /**
     * A Subject is an Observable that allows values to be
     * multicasted to many Observers.
     */
    export class Subject<T, ErrorT = unknown> extends Observable<T> {
        protected observers: Set<Subscriber<T>>;
        protected onSubscribe(subscriber: Subscriber<T>): UnsubscribeFunction;
        protected isStopped: boolean;
        constructor();
        next(a: T): void;
        error(e: ErrorT): void;
        complete(): void;
    }
    /**
     * A subject that guarantees all subscribers receive the same values in the order they were emitted.
     */
    export class OrderedSubject<T> extends Subject<T> {
        private queue;
        private emitting;
        next(a: T): void;
    }
    /**
     * A variant of Subject that requires an initial value and emits its current value whenever it is subscribed to.
     * @see be
     */
    export class BehaviorSubject<T> extends Subject<T> {
        private currentValue;
        constructor(currentValue: T);
        get value(): T;
        protected onSubscribe(subscription: Subscriber<T>): UnsubscribeFunction;
        next(val: T): void;
    }
    /**
     * A variant of Subject that "replays" or emits old values to new subscribers.
     * It buffers a set number of values and will emit those values immediately to any
     * new subscribers in addition to emitting new values to existing subscribers.
     */
    export class ReplaySubject<T, ErrorT = unknown> extends Subject<T, ErrorT> {
        readonly bufferSize: number;
        private buffer;
        private hasError;
        private lastError?;
        constructor(bufferSize?: number);
        protected onSubscribe(subscriber: Subscriber<T>): () => boolean;
        error(val: ErrorT): void;
        next(val: T): void;
    }
    const Undefined: {};
    /**
     * A Reference is a behavior subject that does not require an initial value.
     */
    export class Reference<T> extends Subject<T> {
        protected $value: T | typeof Undefined;
        get hasValue(): boolean;
        get value(): T;
        protected onSubscribe(subscription: Subscriber<T>): UnsubscribeFunction;
        next(val: T): void;
    }
    type ConcatResult<R extends Observable<unknown>[]> = R extends (infer U)[] ? Observable<Merge<U>> : never;
    /**
     * Creates an output Observable which sequentially emits all values from given Observable and then moves on to the next.
     */
    export function concat<R extends Observable<unknown>[]>(...observables: R): ConcatResult<R>;
    /**
     * Creates an Observable that, on subscribe, calls an Observable factory to make an Observable for each new Observer.
     */
    export function defer<T>(fn: () => Subscribable<T>): Observable<T, "none">;
    export function isInterop<T>(obs: object): obs is InteropObservable<T>;
    export function fromArray<T>(input: Array<T>): Observable<T>;
    export function fromPromise<T>(input: Promise<T>): Observable<T>;
    export function fromAsync<T>(input: () => Promise<T>): Observable<T>;
    /**
     * Creates an Observable from an Array, an array-like object, a Promise, an iterable object, or an Observable-like object.
     */
    export function from<T>(input: Array<T> | Promise<T> | Observable<T> | InteropObservable<T>): Observable<T>;
    /**
     * Converts the arguments to an observable sequence.
     */
    export function of<T>(...values: T[]): Observable<T>;
    /**
     * Generates a promise from an observable, the promise will resolve when the observable completes.
     */
    export function toPromise<T, P>(observable: Observable<T, P>): Promise<P extends 'emit1' ? T : T | undefined>;
    export class EmptyError extends Error {
        message: string;
    }
    export function firstValueFrom<T>(observable: Observable<T>): Promise<T>;
    export function operatorNext<T, T2 = T>(fn: (subs: Subscriber<T2>) => NextFunction<T>, unsubscribe?: () => void): (source: Observable<T>) => Observable<T2, "none">;
    export function operator<T, T2 = T>(fn: (subs: Subscriber<T2>, source: Observable<T>) => Observer<T> & {
        next: NextFunction<T>;
        unsubscribe?: UnsubscribeFunction;
    }): Operator<T, T2>;
    /**
     * Applies a given project function to each value emitted by the source Observable, and emits the resulting values as an Observable.
     */
    export function map<T, T2>(mapFn: (val: T) => T2): (source: Observable<T, "none">) => Observable<T2, "none">;
    /**
     * Applies an accumulator function over the source Observable, and returns the accumulated result when the source completes, given an optional seed value.
     */
    export function debounceFunction<F extends (...args: any) => any>(fn: F, delay?: number): ((...args: Parameters<F>) => void) & {
        cancel(): void;
    };
    export function interval(period: number): Observable<void, "none">;
    export function timer(delay: number): Observable<void, "none">;
    /**
     * Emits a value from the source Observable only after a particular time span has passed without another source emission.
     */
    export function debounceTime<T>(time?: number, useTimer?: typeof timer): Operator<T, T>;
    /**
     * Projects each source value to an Observable which is merged in the output Observable,
     * emitting values only from the most recently projected Observable.
     */
    export function switchMap<T, T2>(project: (val: T) => Observable<T2>): (source: Observable<T>) => Observable<T2, "none">;
    /**
     * Projects each source value to an Observable which is merged in the output Observable.
     */
    export function mergeMap<T, T2>(project: (val: T) => Observable<T2>): (source: Observable<T>) => Observable<T2, "none">;
    /**
     * Projects each source value to an Observable which is merged in the output Observable
     * only if the previous projected Observable has completed.
     */
    /**
     * Filter items emitted by the source Observable.
     *
     * @see distinctUntilChanged
     */
    export function filter<T>(fn: (val: T) => boolean): Operator<T, T>;
    /**
     * Emits only the first count values emitted by the source Observable.
     */
    export function take<T>(howMany: number): (source: Observable<T, "none">) => Observable<T, "none">;
    /**
     * Emits values while fn result is truthy.
     */
    export function takeWhile<T>(fn: (val: T) => boolean): (source: Observable<T, "none">) => Observable<T, "none">;
    /**
     * Emits only the first value emitted by the source Observable.
     * Delivers an EmptyError to the Observer's error callback if the Observable completes before any next notification was sent
     */
    export function first<T>(): Operator<T, T>;
    /**
     * Perform a side effect for every emission on the source Observable,
     * but return an Observable that is identical to the source.
     */
    export function tap<T>(fn: (val: T) => void): Operator<T, T>;
    /**
     * Catches errors on the observable.
     *
     * @param selector A function that takes as arguments the error `err`,  and `source`, which
     *  is the source observable. The observable
     *  returned will be used to continue the observable chain.
     *
     */
    export function catchError<T, O extends T | never>(selector: (err: unknown, source: Observable<T>) => Observable<O> | void): Operator<T, T>;
    /**
     * Returns an Observable that emits all items emitted by the source Observable
     * that are distinct by comparison from the previous item.
     */
    export function distinctUntilChanged<T>(): Operator<T, T>;
    export function select<StateT, K extends keyof StateT>(key: K): (source: Observable<StateT, "none">) => Observable<StateT[K], "none">;
    export function share<T>(): Operator<T, T>;
    /**
     * Returns an observable that shares a single subscription to the underlying sequence containing only the last notification.
     */
    export function publishLast<T>(): Operator<T, T>;
    type MergeResult<R extends Observable<unknown>[]> = R extends (infer U)[] ? Observable<Merge<U>> : never;
    /**
     * Creates an output Observable which concurrently emits all values from every given input Observable.
     */
    export function merge<R extends Observable<unknown>[]>(...observables: R): MergeResult<R>;
    /**
     * Combines multiple Observables to create an Observable whose values are calculated from the values, in order, of each of its input Observables.
     */
    export function zip<T extends Observable<unknown>[]>(...observables: T): Observable<PickObservable<T>>;
    /**
     * Combines multiple Observables to create an Observable whose values are calculated from the
     * latest values of each of its input Observables.
     */
    export function combineLatest<T extends Observable<unknown>[]>(...observables: T): Observable<PickObservable<T>>;
    /**
     * Returns an Observable that mirrors the source Observable, but will call a
     * specified function when the source terminates on complete or error.
     */
    export function finalize<T>(unsubscribe: () => void): Operator<T, T>;
    export function ignoreElements(): Operator<never, never>;
    /**
     * Creates an Observable that emits no items to the Observer and immediately emits an error notification.
     */
    export function throwError(error: unknown): Observable<never, "none">;
    /**
     * An observable that completes on subscription.
     */
    export const EMPTY: Observable<never, "none">;
    /**
     * Creates a new Behavior Subject.
     */
    export function be<T>(initialValue: T): BehaviorSubject<T>;
    /**
     * Creates a new Observable
     */
    export function observable<T>(subscribe: SubscribeFunction<T>): Observable<T, "none">;
    /**
     * Creates a new Subject
     */
    export function subject<T>(): Subject<T, unknown>;
    /**
     * Creates a new Reference object. A reference is a Behavior Subject that does not require an initial value.
     */
    export function ref<T>(): Reference<T>;
    export const operators: {
        readonly catchError: typeof catchError;
        readonly debounceTime: typeof debounceTime;
        readonly distinctUntilChanged: typeof distinctUntilChanged;
        readonly filter: typeof filter;
        readonly finalize: typeof finalize;
        readonly first: typeof first;
        readonly ignoreElements: typeof ignoreElements;
        readonly map: typeof map;
        readonly mergeMap: typeof mergeMap;
        readonly publishLast: typeof publishLast;
        readonly select: typeof select;
        readonly share: typeof share;
        readonly switchMap: typeof switchMap;
        readonly take: typeof take;
        readonly takeWhile: typeof takeWhile;
        readonly tap: typeof tap;
    };
    export interface Observable<T> {
        catchError<T2 extends T | never>(selector: (err: unknown, source: Observable<T>) => Observable<T2> | void): Observable<T>;
        debounceTime(time?: number, timer?: (delay: number) => Observable<void>): Observable<T>;
        distinctUntilChanged(): Observable<T>;
        filter<T2 = T>(fn: (val: T) => boolean): Observable<T2>;
        finalize(fn: () => void): Observable<T>;
        first(): Observable<T>;
        map<T2>(mapFn: (val: T) => T2): Observable<T2>;
        mergeMap<T2>(project: (val: T) => Observable<T2>): Observable<T2>;
        publishLast(): Observable<T>;
        select<K extends keyof T>(key: K): Observable<T[K]>;
        share(): Observable<T>;
        switchMap<T2>(project: (val: T) => Observable<T2>): Observable<T2>;
        take(howMany: number): Observable<T>;
        takeWhile(fn: (val: T) => boolean): Observable<T>;
        tap(tapFn: (val: T) => void): Observable<T>;
        ignoreElements(): Observable<never>;
    }
}
/// <amd-module name="@cxl/ui/dom.js" />
declare module "@cxl/ui/dom.js" {
    import { Observable, Subject, Subscriber, Subscription } from "@cxl/ui/rx.js";
    global {
        interface Node {
            $$attributeObserver?: AttributeObserver;
            $$childrenObserver?: ChildrenObserver;
        }
    }
    export type ElementContent = string | Node | undefined;
    export type TemplateContent = string | Element | HTMLTemplateElement | NodeList;
    export function empty(el: Element | DocumentFragment): void;
    export function setContent(el: Element, content: ElementContent): void;
    export function on<K extends keyof WindowEventMap>(element: Window, event: K, options?: AddEventListenerOptions): Observable<WindowEventMap[K]>;
    export function on<K extends keyof HTMLElementEventMap>(element: EventTarget, event: K, options?: AddEventListenerOptions): Observable<HTMLElementEventMap[K]>;
    export function on<T extends HTMLElement, K extends string>(element: T, event: K, options?: AddEventListenerOptions): Observable<CustomEvent<EventDetail<T, K>>>;
    export function onKeypress(el: Element | Window, key?: string, options?: AddEventListenerOptions): Observable<KeyboardEvent, "none">;
    export function onAction(el: Element): Observable<MouseEvent, "none">;
    export function onReady(): Observable<boolean, "none">;
    export function onLoad(): Observable<boolean, "none">;
    export function onFontsReady(): Observable<FontFaceSet>;
    export function getShadow(el: Element): ShadowRoot;
    export function setAttribute(el: Element, attr: string, val: unknown): unknown;
    export function trigger<K extends keyof HTMLElementEventMap | keyof WindowEventMap>(el: EventTarget, event: K, options?: CustomEventInit): void;
    export function trigger<T extends HTMLElement, K extends string>(el: T, event: K, options: CustomEventInit<EventDetail<T, K>>): void;
    export type AttributeMutationEvent<T extends EventTarget> = {
        type: 'attribute';
        target: T;
        value: unknown;
    };
    export type MutationEvent<T extends EventTarget = EventTarget> = {
        type: 'added' | 'removed';
        target: T;
        value: Node;
    } | {
        type: 'characterData';
        target: T;
    } | AttributeMutationEvent<T>;
    export class AttributeObserver extends Subject<AttributeMutationEvent<EventTarget>> {
        element: Node;
        observer?: MutationObserver;
        bindings?: Subscription[];
        $onMutation(events: MutationRecord[]): void;
        $initializeNative(element: Node): void;
        constructor(element: Node);
        protected onSubscribe(subscription: Subscriber<MutationEvent<EventTarget>>): () => void;
        disconnect(): void;
        trigger(attributeName: string): void;
    }
    export function observeChildren(el: Element): Observable<void>;
    export function onChildrenMutation(el: Element): ChildrenObserver;
    export function onAttributeChange(el: Element): AttributeObserver;
    export class ChildrenObserver extends Subject<MutationEvent> {
        private element;
        private observer?;
        constructor(element: Element);
        $handleEvent(ev: MutationRecord): void;
        protected onSubscribe(subscription: Subscriber<MutationEvent<EventTarget>>): () => void;
    }
    export function onHashChange(): Observable<string, "none">;
    export function onHistoryChange(): Observable<any, "none">;
    export function onLocation(): Observable<Location, "none">;
    export const animationFrame: Observable<number, "none">;
    export function findNextNode<T extends ChildNode>(el: T, fn: (el: T) => boolean, direction?: 'nextSibling' | 'previousSibling'): T | undefined;
    export function findNextNodeBySelector(host: Element, el: Element, selector: string, direction?: number): Element | null;
    export function onResize(el: Element): Observable<unknown, "none">;
    export function insert(el: Element, content: ElementContent): void;
    export function fileReaderString(file: Blob): Observable<string, "none">;
    export function onMutation(target: Node, options?: MutationObserverInit): Observable<MutationEvent<EventTarget>, "none">;
    export function onIntersection(target: Element): Observable<IntersectionObserverEntry, "none">;
    export interface ElementWithValue<T> extends HTMLElement {
        value: T;
    }
    export function onValue<T extends ElementWithValue<R>, R = T['value']>(el: T): Observable<R, "none">;
    export function onVisible(target: Element): Observable<boolean, "none">;
    export function isHidden(target: HTMLElement): boolean;
    export function isFocusable(el: HTMLElement): boolean;
    export function findFocusable(host: Element | ShadowRoot): HTMLElement | undefined;
    export function findLastFocusable(host: Element | ShadowRoot): HTMLElement | undefined;
    export function findFocusableAll(host: Element): HTMLElement[];
    export function setClassName(el: HTMLElement): import("@cxl/ui/rx.js").Operator<string, string>;
    export function debounceImmediate<A extends unknown[], R>(fn: (...a: A) => R): (this: unknown, ...args: A) => void;
    export function debounceRaf<A extends unknown[], R>(fn: (...a: A) => R): (this: unknown, ...args: A) => void;
    /**
     * debounce using requestAnimationFrame
     */
    export function raf<T>(fn?: (val: T) => void): import("@cxl/ui/rx.js").Operator<T, T>;
    export const hovered: ($: Element) => Observable<boolean, "none">;
    export const focused: ($: Element) => Observable<boolean, "none">;
    export function nodeSort(a: Node, b: Node): 1 | -1;
    export function sortNodes<T extends Node>(nodes: T[]): T[];
    export type EventDetail<T, K extends string> = T[Extract<keyof T, `on${K}`>] extends ((e: CustomEvent<infer D>) => void) | undefined ? D : never;
}
/// <amd-module name="@cxl/ui/tsx.js" />
declare module "@cxl/ui/tsx.js" {
    import { Observable } from "@cxl/ui/rx.js";
    global {
        namespace dom {
            namespace JSX {
                type ElementClass = Bindable;
                interface ElementAttributesProperty {
                    jsxAttributes: unknown;
                }
                interface ElementChildrenAttribute {
                    children: {};
                }
                type Element = Node;
                type IntrinsicElements = {
                    [P in keyof HTMLElementTagNameMap]: NativeType<HTMLElementTagNameMap[P]>;
                };
                interface IntrinsicClassAttributes<T> {
                    $?: Binding<T, unknown> | Observable<unknown>;
                }
            }
        }
    }
    export type Binding<T, DataT> = (el: T) => Observable<DataT>;
    export type Child = string | Node | number | ((host: Bindable) => Node) | undefined | Observable<unknown>;
    export type Children = Child | Child[];
    export type NativeChild = string | number | Node | undefined;
    export type NativeChildren = NativeChild | NativeChild[];
    export type NativeType<T> = {
        [K in keyof Omit<T, 'children'>]?: T[K];
    } & {
        children?: NativeChildren;
    };
    export type Disallowed = Observable<unknown> | Function;
    export type AttributeType<T> = {
        [K in keyof Omit<T, 'children' | '$'>]?: T[K] extends Disallowed ? never : T[K] | Observable<T[K]>;
    } & {
        children?: Children;
    };
    export interface Bindable extends Node {
        bind(binding: Observable<unknown>): void;
    }
    export function expression(host: Bindable, binding: Observable<unknown>): Text;
    export function renderChildren(host: Bindable | Node, children: Children, appendTo?: Node): void;
    interface ComponentConstructor<T extends Bindable> {
        create(): T;
    }
    export function dom<T extends Bindable>(elementType: ComponentConstructor<T>, attributes?: AttributeType<T>, ...children: Child[]): T;
    export function dom<T, T2>(elementType: (attributes?: T2) => Bindable, attributes?: T2, ...children: Child[]): T;
    export function dom<K extends keyof HTMLElementTagNameMap>(elementType: K, attributes?: NativeType<HTMLElementTagNameMap[K]>, ...children: Child[]): HTMLElementTagNameMap[K];
    export default dom;
}
/// <amd-module name="@cxl/ui/component.js" />
declare module "@cxl/ui/component.js" {
    import { AttributeType, Children } from "@cxl/ui/tsx.js";
    import { Observable, Operator, OrderedSubject } from "@cxl/ui/rx.js";
    type RenderFunction<T> = (node: T) => void;
    type Augmentation<T extends Component> = (host: T) => Node | Comment | Observable<unknown> | void;
    type ComponentConstructor = {
        tagName: string;
        observedAttributes: string[];
        create(): Component;
    };
    export type ComponentAttributeName<T> = keyof T;
    export interface AttributeEvent<T> {
        target: T;
        attribute: ComponentAttributeName<T>;
    }
    export class Bindings {
        private subscriptions?;
        bindings?: Observable<unknown>[];
        bind(binding: Observable<unknown>): void;
        connect(): void;
        disconnect(): void;
    }
    export abstract class Component extends HTMLElement {
        static tagName: string;
        static observedAttributes: string[];
        static create(): Component;
        private $$bindings?;
        private $$prebind?;
        protected jsxAttributes: AttributeType<this>;
        readonly render?: (node: HTMLElement) => void;
        readonly attributes$: OrderedSubject<unknown>;
        Shadow: (p: {
            children: Children;
        }) => Component;
        Slot: (p: {
            selector: string;
            name?: string;
            className?: string;
        }) => HTMLSlotElement;
        bind(obs: Observable<unknown>): void;
        protected connectedCallback(): void;
        protected disconnectedCallback(): void;
        protected attributeChangedCallback(name: keyof this, oldValue: string | null, value: string | null): void;
    }
    export function pushRender<T extends Component>(proto: T, renderFn: RenderFunction<T>): void;
    export function appendShadow<T extends Component>(host: T, child: Node | Observable<unknown>): void;
    export function augment<T extends Component>(constructor: typeof Component, decorators: Augmentation<T>[]): void;
    export function registerComponent(tagName: string, ctor: ComponentConstructor): void;
    export function Augment(): (ctor: ComponentConstructor) => void;
    export function Augment<T extends Component>(...augs: [string | Augmentation<T> | void, ...Augmentation<T>[]]): (ctor: ComponentConstructor) => void;
    export function connect<T extends Component>(bindFn: (node: T) => void): (host: T) => void;
    export function onUpdate<T extends Component>(host: T): Observable<T, "none">;
    /**
     * Fires when connected and on attribute change
     */
    export function update<T extends Component>(fn: (node: T) => void): (host: T) => void;
    export function attributeChanged<T extends Component, K extends ComponentAttributeName<T>>(element: T, attribute: K): Observable<T[K]>;
    export function get<T extends Component, K extends ComponentAttributeName<T>>(element: T, attribute: K): Observable<T[K]>;
    interface AttributeOptions<T extends Component> {
        persist?: boolean;
        persistOperator?: Operator<AttributeEvent<T>, AttributeEvent<T>>;
        observe?: boolean;
        render?: RenderFunction<T>;
        parse?(val: unknown, component: T): unknown;
    }
    export function Attribute(options?: AttributeOptions<Component>): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
    export function StyleAttribute(): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
    export function EventAttribute(): <T extends Component>(target: T, attribute: keyof T, descriptor?: PropertyDescriptor) => any;
    export function Property(): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
    export function getRegisteredComponents(): {
        [x: string]: typeof Component;
    };
    export class Span extends Component {
    }
    export function Slot(): HTMLSlotElement;
}
/// <amd-module name="@cxl/ui/css.js" />
declare module "@cxl/ui/css.js" {
    export type StyleDefinition<T extends Theme = Theme> = {
        [K in keyof StrictStyleDefinition<T>]?: StrictStyleDefinition<T>[K] | Variable<StrictStyleDefinition<T>[K]>;
    };
    export type BaseColor = RGBA;
    export type CSSStyle = {
        [P in keyof CSSStyleDeclaration]?: string | number;
    };
    export type Color<T extends Theme> = keyof T['colors'] | BaseColor | 'currentColor' | 'inherit' | 'transparent';
    export type Percentage = '50%' | '100%' | CustomPercentage;
    export type Calc = `calc(${string})`;
    export type Length = number | Percentage | Calc | 'auto';
    export type ColorVariables<T> = {
        [K in keyof T]: string;
    };
    export type VariableList<T extends Theme> = T['variables'] & ColorVariables<T['colors']>;
    export type FlexAlign = 'normal' | 'stretch' | 'center' | 'start' | 'end' | 'flex-start' | 'flex-end' | 'baseline';
    export type StyleKey<T extends Theme> = keyof StrictStyleDefinition<T>;
    export interface Variables {
    }
    export interface Colors {
    }
    export interface FontDefinition {
        family: string;
        url: string;
        weight?: string;
    }
    export interface Typography {
        default: CSSStyle;
    }
    export interface StrictStyleDefinition<T extends Theme> {
        alignItems: FlexAlign;
        alignSelf: FlexAlign;
        animation: keyof T['animation'];
        animationDuration: string;
        backgroundImage: string;
        backgroundClip: 'content-box' | 'border-box';
        backgroundColor: Color<T>;
        backgroundSize: 'cover' | 'contain';
        backgroundPosition: 'center';
        backgroundRepeat: 'no-repeat' | 'repeat' | 'repeat-x' | 'repeat-y';
        borderBottom: Length;
        borderLeft: Length;
        borderRight: Length;
        borderTop: Length;
        borderColor: Color<T>;
        borderWidth: number;
        borderRadius: Length;
        borderStyle: 'solid' | 'dashed' | 'dotted' | 'double' | 'none';
        boxShadow: BoxShadow<T> | 'none';
        boxSizing: 'border-box';
        clipPath: string;
        fill: Color<T>;
        stroke: Color<T>;
        elevation: 0 | 1 | 2 | 3 | 4 | 5;
        fontSize: number | 'inherit';
        fontStyle: 'italic';
        touchAction: 'none' | 'pan-y' | 'pan-x';
        translateX: Length;
        translateY: Length;
        rowGap: Length;
        columnGap: Length;
        gridAutoColumns: string;
        gridColumnEnd: string;
        gridAutoFlow: 'column' | 'row';
        gridTemplateColumns: string;
        gridTemplateRows: string;
        gridRow: string;
        prepend: string;
        rotate: number;
        scaleX: number;
        scaleY: number;
        font: keyof T['typography'];
        color: Color<T>;
        paddingLeft: Length;
        paddingRight: Length;
        paddingTop: Length;
        paddingBottom: Length;
        marginLeft: number | 'auto';
        marginRight: number | 'auto';
        marginTop: number | 'auto';
        marginBottom: number | 'auto';
        opacity: number;
        outline: number | string;
        outlineOffset: number;
        order: number;
        overflowY: 'hidden' | 'visible' | 'auto';
        overflowX: 'hidden' | 'visible' | 'auto';
        visibility: 'hidden' | 'visible';
        transformOrigin: string;
        overflowScrolling: string;
        lineHeight: number | 'unset';
        listStyleImage: string;
        listStylePosition: 'inside' | 'outside';
        listStyleType: 'none' | 'inherit' | 'initial' | 'unset';
        width: Length | 'max-content' | 'min-content';
        tableLayout: 'fixed' | 'auto';
        top: Length;
        left: Length;
        right: Length;
        bottom: Length;
        filter: string;
        flexGrow: number;
        flexShrink: number;
        flexBasis: Length;
        flexDirection: string;
        flexWrap: 'wrap';
        justifyContent: string;
        pointerEvents: string;
        cursor: string;
        display: 'block' | 'inline' | 'table' | 'flex' | 'inline-grid' | 'grid' | 'table-row' | 'table-caption' | 'table-row-group' | 'table-cell' | 'contents' | 'none' | 'initial' | 'inline-flex' | 'inline-block' | 'inherit';
        position: 'static' | 'relative' | 'absolute' | 'sticky' | 'fixed';
        userSelect: string;
        textAlign: string;
        textDecoration: string;
        textOverflow: 'ellipsis';
        textTransform: 'uppercase' | 'capitalize' | 'none';
        transition: string;
        height: Length;
        minHeight: Length | 'none';
        minWidth: Length | 'none';
        maxHeight: Length | 'none';
        maxWidth: Length | 'none';
        mixBlendMode: 'difference';
        variables: Partial<VariableList<T>>;
        verticalAlign: 'top' | 'middle' | 'bottom' | 'super' | 'sub' | 'text-top' | 'text-bottom' | 'baseline';
        willChange: 'transform';
        whiteSpace: 'nowrap' | 'pre-wrap' | 'pre';
        wordBreak: 'break-all';
        zIndex: number;
    }
    export interface BoxShadow<T extends Theme = Theme> {
        offsetX: number;
        offsetY: number;
        blurRadius: number;
        spread: number;
        color: Color<T>;
    }
    export type StylesOnly<T extends Theme> = {
        [key: string]: StyleDefinition<T>;
    };
    export type Styles<T extends Theme> = StylesOnly<T> | {
        '@small'?: StylesOnly<T>;
        '@medium'?: StylesOnly<T>;
        '@large'?: StylesOnly<T>;
        '@xlarge'?: StylesOnly<T>;
        '@xxlarge'?: StylesOnly<T>;
    };
    export type BreakpointKey = 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge';
    export type CSSUnit = 'px' | 'em' | 'rem';
    export interface Breakpoints {
        xsmall: number;
        small: number;
        large: number;
        medium: number;
        xlarge: number;
        xxlarge: number;
    }
    export interface AnimationDefinition {
        kf: Keyframe[];
        options?: KeyframeAnimationOptions;
    }
    export interface Animation {
        none: undefined;
    }
    export interface Theme {
        animation: Animation;
        colors: Colors;
        typography: {
            default: CSSStyle;
        };
        variables: Variables;
        breakpoints: Breakpoints;
        imports?: readonly string[];
        unit: CSSUnit;
    }
    export interface RGBA {
        readonly a: number;
        readonly r: number;
        readonly g: number;
        readonly b: number;
        toString(): string;
    }
    export type CustomPercentage = {
        __pct: true;
        toString(): string;
    };
    export function boxShadow<T extends Theme>(offsetX: number, offsetY: number, blurRadius: number, spread: number, color: Color<T>): {
        offsetX: number;
        offsetY: number;
        blurRadius: number;
        spread: number;
        color: Color<T>;
    };
    export function pct(n: number): CustomPercentage;
    export const defaultTheme: Theme;
    export function padding(paddingTop: number | 'auto', paddingRight?: number | "auto", paddingBottom?: number | "auto", paddingLeft?: number | "auto"): {
        paddingTop: number | "auto";
        paddingRight: number | "auto";
        paddingBottom: number | "auto";
        paddingLeft: number | "auto";
    };
    export function margin(marginTop: number | 'auto', marginRight?: number | "auto", marginBottom?: number | "auto", marginLeft?: number | "auto"): {
        marginTop: number | "auto";
        marginRight: number | "auto";
        marginBottom: number | "auto";
        marginLeft: number | "auto";
    };
    export function border(borderTop: number | 'auto', borderRight?: number | "auto", borderBottom?: number | "auto", borderLeft?: number | "auto"): {
        borderTop: number | "auto";
        borderRight: number | "auto";
        borderBottom: number | "auto";
        borderLeft: number | "auto";
    };
    export function rgba(r: number, g: number, b: number, a?: number): RGBA;
    export function mask({ r, g, b, a }: RGBA): string;
    export function renderVariables(variables: Variables): string;
    export type PartialTheme = {
        variables?: Partial<Variables>;
        typography?: Record<string, CSSStyle>;
        colors?: Colors;
        imports?: readonly string[];
        globalCss?: string;
        override?: Record<string, string>;
    };
    export function renderGlobal(theme: PartialTheme): string;
    export class Variable<T> {
        readonly name: string;
        constructor(name: string);
        readonly __brand?: T;
        toString(): string;
    }
    export const White: RGBA;
    export const White8: string;
    export const White12: string;
    export const White87: string;
    export function buildTheme<T extends Theme>(theme: T): {
        inline: (def: StyleDefinition) => string;
        render: (styles: Styles<T>, baseSelector?: string) => string;
        applyTheme: (container?: HTMLHeadElement) => void;
        rootStyles: HTMLStyleElement;
        variable: {
            <K extends keyof T["colors"]>(name: K): Variable<T["colors"][K]>;
            <K extends keyof T["variables"]>(name: K): Variable<T["variables"][K]>;
        };
        style(styles: Styles<T>, selector?: string): () => HTMLStyleElement;
        baseColor(name: keyof T["colors"]): string;
    };
}
/// <amd-module name="@cxl/ui/template.js" />
declare module "@cxl/ui/template.js" {
    import { Observable } from "@cxl/ui/rx.js";
    export interface InsertEvent<T, K> {
        type: 'insert';
        item: T;
        key: K;
    }
    export interface RemoveEvent<K> {
        type: 'remove';
        key: K;
    }
    export interface EmptyEvent {
        type: 'empty';
    }
    export type ListEvent<T, K> = InsertEvent<T, K> | RemoveEvent<K> | EmptyEvent;
    import type { Bindable } from "@cxl/ui/tsx.js";
    export function sortBy<T, K extends keyof T = keyof T>(key: K): (a: T, b: T) => 1 | 0 | -1;
    export function getSearchRegex(term: string, flags?: string): RegExp;
    export function portal(id: string): (el: HTMLElement) => Observable<unknown, "none">;
    export function teleport(el: Node, portalName: string): Observable<HTMLElement, "none">;
    export class Marker {
        children: Node[];
        node: Comment;
        insert(content: Node, nextNode?: Node): void;
        remove(node: Node): void;
        empty(): void;
    }
    export function list<T, K>(source: Observable<ListEvent<T, K>>, renderFn: (item: T) => Node): (host: Bindable) => Comment;
    export function render<T>(source: Observable<T>, renderFn: (item: T) => Node, loading?: () => Node, error?: (e: unknown) => Node): (host: Bindable) => Comment;
    export function each<T>(source: Observable<Iterable<T>>, renderFn: (item: T, index: number, source: Iterable<T>) => Node | undefined, empty?: () => Node): (host: Bindable) => Comment;
    export function $onAction<T extends Element>(cb: (ev: KeyboardEvent | MouseEvent) => void): (el: T) => Observable<MouseEvent, "none">;
    export function escapeHtml(str: string): string;
}
/// <amd-module name="@cxl/ui/storage.js" />
declare module "@cxl/ui/storage.js" {
    export const storage: {
        /**
         * Retrieves a value from the localStorage given a key.
         * If the key does not exist, it returns an empty string.
         * Catches and logs any potential errors during the retrieval process,
         * which could occur if there are issues accessing localStorage.
         */
        get(key: string): string;
        /**
         Sets a value in the localStorage for a given key.
    If setting the item fails, typically due to storage being full
    or access restrictions, it catches and logs the error to the console.
         */
        set(key: string, name: string): void;
    };
}
/// <amd-module name="@cxl/ui/theme.js" />
declare module "@cxl/ui/theme.js" {
    import { Styles as CssStyles, StyleDefinition, PartialTheme, Color, RGBA } from "@cxl/ui/css.js";
    import type { Component } from "@cxl/ui/component.js";
    type ArrayElement<ArrayType extends readonly unknown[]> = ArrayType extends readonly (infer ElementType)[] ? ElementType : never;
    export interface SvgIconAttributes {
        className?: string;
        width?: number;
        height?: number;
        alt?: string;
    }
    export type StyleDef = StyleDefinition<UiTheme>;
    export type UiTheme = typeof theme;
    export type Styles = CssStyles<UiTheme>;
    export type ThemeColor = keyof UiTheme['colors'];
    export type SurfaceColorValue = ArrayElement<typeof surfaceColors> | 'inherit' | 'transparent';
    export type AnimationKey = keyof UiTheme['animation'];
    export type BaseColors = typeof baseColors;
    export interface IconDef {
        id: string;
        icon(prop?: SvgIconAttributes): SVGSVGElement;
    }
    export const baseColors: {
        primary: RGBA;
        onPrimary: RGBA;
        secondary: RGBA;
        onSecondary: RGBA;
        surface: RGBA;
        onSurface: RGBA;
        background: RGBA;
        onBackground: RGBA;
    };
    export const onThemeChange: import("@cxl/ui/rx.js").Reference<(PartialTheme & {
        css: string;
        name: string;
    }) | undefined>;
    export const theme: {
        animation: {
            none: undefined;
            flash: {
                kf: {
                    opacity: number[];
                };
                options: {
                    iterations: number;
                    easing: string;
                };
            };
            spin: {
                kf: {
                    rotate: string[];
                };
                options: {
                    iterations: number;
                    duration: number;
                    easing: string;
                };
            };
            pulse: {
                kf: {
                    rotate: string[];
                };
                options: {
                    iterations: number;
                    easing: string;
                    duration: number;
                };
            };
            expand: {
                kf: {
                    scale: number[];
                };
                options: {
                    iterations: number;
                    easing: string;
                };
            };
            zoomIn: {
                kf: {
                    scale: number[];
                };
            };
            zoomOut: {
                kf: {
                    scale: number[];
                };
            };
            fadeIn: {
                kf: {
                    opacity: number;
                }[];
                options: {
                    easing: string;
                    fill: string;
                };
            };
            fadeOut: {
                kf: ({
                    opacity: number;
                    visibility?: undefined;
                } | {
                    opacity: number;
                    visibility: string;
                })[];
                options: {
                    easing: string;
                    fill: string;
                };
            };
            shakeX: {
                kf: {
                    translate: (string | number)[];
                };
            };
            shakeY: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutLeft: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInLeft: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutRight: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInRight: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInUp: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInDown: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutUp: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutDown: {
                kf: {
                    translate: (string | number)[];
                };
            };
            wait: {
                kf: {
                    transform: string;
                }[];
                options: {
                    duration: number;
                    iterations: number;
                    easing: string;
                };
            };
            focus: {
                kf: ({
                    offset: number;
                    filter: string;
                } | {
                    filter: string;
                    offset?: undefined;
                })[];
                options: {
                    duration: number;
                };
            };
            spinnerstroke: {
                options: {
                    duration: number;
                    iterations: number;
                    easing: string;
                };
                kf: {
                    offset: number;
                    strokeDashoffset: string;
                    transform: string;
                }[];
            };
        };
        variables: {
            speed: string;
            font: string;
            fontMonospace: string;
            maskOpacity8: number;
            maskOpacity10: number;
            maskOpacity12: number;
            scrollbarWidth: string;
            scrollbarHeight: string;
            scrollbarForeground: string;
        };
        typography: {
            default: {
                fontWeight: number;
                fontFamily: string;
                fontSize: string;
                letterSpacing: string;
            };
            caption: {
                fontSize: string;
                letterSpacing: string;
            };
            h1: {
                fontWeight: number;
                fontSize: string;
                letterSpacing: string;
            };
            h2: {
                fontWeight: number;
                fontSize: string;
                letterSpacing: string;
            };
            h3: {
                fontSize: string;
            };
            h4: {
                fontSize: string;
                letterSpacing: string;
            };
            h5: {
                fontSize: string;
            };
            h6: {
                fontSize: string;
                fontWeight: number;
                letterSpacing: string;
            };
            body2: {
                fontSize: string;
                letterSpacing: string;
            };
            subtitle: {
                letterSpacing: string;
            };
            subtitle2: {
                fontSize: string;
                fontWeight: number;
                letterSpacing: string;
            };
            button: {
                fontSize: string;
                fontWeight: number;
                letterSpacing: string;
                textTransform: string;
            };
            code: {
                fontFamily: string;
                fontSize: string;
            };
        };
        colors: {
            error: RGBA;
            errorOnPrimary: RGBA;
            onError: RGBA;
            warning: RGBA;
            onWarning: RGBA;
            success: RGBA;
            onSuccess: RGBA;
            darkGray: RGBA;
            onDarkGray: RGBA;
            fieldMask: string;
            primaryLight: RGBA;
            onPrimaryLight: RGBA;
            secondaryLight: RGBA;
            onSecondaryLight: RGBA;
            headerText: RGBA;
            onSurface8: RGBA;
            onSurface12: RGBA;
            divider: RGBA;
            shadow: RGBA;
            primary: RGBA;
            onPrimary: RGBA;
            secondary: RGBA;
            onSecondary: RGBA;
            surface: RGBA;
            onSurface: RGBA;
            background: RGBA;
            onBackground: RGBA;
        };
        imports: string[] | undefined;
        globalCss: string;
        global: {
            readonly '@a': {
                readonly color: "primary";
            };
            readonly 'cxl-selection,::selection': {
                readonly backgroundColor: "secondary";
                readonly color: "onSecondary";
            };
            readonly '*': {
                readonly boxSizing: "border-box";
                readonly transition: "opacity var(--cxl-speed), transform var(--cxl-speed), box-shadow var(--cxl-speed), filter var(--cxl-speed), rotate var(--cxl-speed)";
            };
        };
        breakpoints: import("@cxl/ui/css.js").Breakpoints;
        unit: import("@cxl/ui/css.js").CSSUnit;
    };
    export const FontValues: string[];
    export const applyTheme: (container?: HTMLHeadElement) => void, baseColor: (name: "error" | "background" | "shadow" | "errorOnPrimary" | "onError" | "warning" | "onWarning" | "success" | "onSuccess" | "darkGray" | "onDarkGray" | "fieldMask" | "primaryLight" | "onPrimaryLight" | "secondaryLight" | "onSecondaryLight" | "headerText" | "onSurface8" | "onSurface12" | "divider" | "primary" | "secondary" | "onSecondary" | "surface" | "onPrimary" | "onSurface" | "onBackground") => string, render: (styles: CssStyles<{
        animation: {
            none: undefined;
            flash: {
                kf: {
                    opacity: number[];
                };
                options: {
                    iterations: number;
                    easing: string;
                };
            };
            spin: {
                kf: {
                    rotate: string[];
                };
                options: {
                    iterations: number;
                    duration: number;
                    easing: string;
                };
            };
            pulse: {
                kf: {
                    rotate: string[];
                };
                options: {
                    iterations: number;
                    easing: string;
                    duration: number;
                };
            };
            expand: {
                kf: {
                    scale: number[];
                };
                options: {
                    iterations: number;
                    easing: string;
                };
            };
            zoomIn: {
                kf: {
                    scale: number[];
                };
            };
            zoomOut: {
                kf: {
                    scale: number[];
                };
            };
            fadeIn: {
                kf: {
                    opacity: number;
                }[];
                options: {
                    easing: string;
                    fill: string;
                };
            };
            fadeOut: {
                kf: ({
                    opacity: number;
                    visibility?: undefined;
                } | {
                    opacity: number;
                    visibility: string;
                })[];
                options: {
                    easing: string;
                    fill: string;
                };
            };
            shakeX: {
                kf: {
                    translate: (string | number)[];
                };
            };
            shakeY: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutLeft: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInLeft: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutRight: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInRight: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInUp: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInDown: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutUp: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutDown: {
                kf: {
                    translate: (string | number)[];
                };
            };
            wait: {
                kf: {
                    transform: string;
                }[];
                options: {
                    duration: number;
                    iterations: number;
                    easing: string;
                };
            };
            focus: {
                kf: ({
                    offset: number;
                    filter: string;
                } | {
                    filter: string;
                    offset?: undefined;
                })[];
                options: {
                    duration: number;
                };
            };
            spinnerstroke: {
                options: {
                    duration: number;
                    iterations: number;
                    easing: string;
                };
                kf: {
                    offset: number;
                    strokeDashoffset: string;
                    transform: string;
                }[];
            };
        };
        variables: {
            speed: string;
            font: string;
            fontMonospace: string;
            maskOpacity8: number;
            maskOpacity10: number;
            maskOpacity12: number;
            scrollbarWidth: string;
            scrollbarHeight: string;
            scrollbarForeground: string;
        };
        typography: {
            default: {
                fontWeight: number;
                fontFamily: string;
                fontSize: string;
                letterSpacing: string;
            };
            caption: {
                fontSize: string;
                letterSpacing: string;
            };
            h1: {
                fontWeight: number;
                fontSize: string;
                letterSpacing: string;
            };
            h2: {
                fontWeight: number;
                fontSize: string;
                letterSpacing: string;
            };
            h3: {
                fontSize: string;
            };
            h4: {
                fontSize: string;
                letterSpacing: string;
            };
            h5: {
                fontSize: string;
            };
            h6: {
                fontSize: string;
                fontWeight: number;
                letterSpacing: string;
            };
            body2: {
                fontSize: string;
                letterSpacing: string;
            };
            subtitle: {
                letterSpacing: string;
            };
            subtitle2: {
                fontSize: string;
                fontWeight: number;
                letterSpacing: string;
            };
            button: {
                fontSize: string;
                fontWeight: number;
                letterSpacing: string;
                textTransform: string;
            };
            code: {
                fontFamily: string;
                fontSize: string;
            };
        };
        colors: {
            error: RGBA;
            errorOnPrimary: RGBA;
            onError: RGBA;
            warning: RGBA;
            onWarning: RGBA;
            success: RGBA;
            onSuccess: RGBA;
            darkGray: RGBA;
            onDarkGray: RGBA;
            fieldMask: string;
            primaryLight: RGBA;
            onPrimaryLight: RGBA;
            secondaryLight: RGBA;
            onSecondaryLight: RGBA;
            headerText: RGBA;
            onSurface8: RGBA;
            onSurface12: RGBA;
            divider: RGBA;
            shadow: RGBA;
            primary: RGBA;
            onPrimary: RGBA;
            secondary: RGBA;
            onSecondary: RGBA;
            surface: RGBA;
            onSurface: RGBA;
            background: RGBA;
            onBackground: RGBA;
        };
        imports: string[] | undefined;
        globalCss: string;
        global: {
            readonly '@a': {
                readonly color: "primary";
            };
            readonly 'cxl-selection,::selection': {
                readonly backgroundColor: "secondary";
                readonly color: "onSecondary";
            };
            readonly '*': {
                readonly boxSizing: "border-box";
                readonly transition: "opacity var(--cxl-speed), transform var(--cxl-speed), box-shadow var(--cxl-speed), filter var(--cxl-speed), rotate var(--cxl-speed)";
            };
        };
        breakpoints: import("@cxl/ui/css.js").Breakpoints;
        unit: import("@cxl/ui/css.js").CSSUnit;
    }>, baseSelector?: string) => string, style: (styles: CssStyles<{
        animation: {
            none: undefined;
            flash: {
                kf: {
                    opacity: number[];
                };
                options: {
                    iterations: number;
                    easing: string;
                };
            };
            spin: {
                kf: {
                    rotate: string[];
                };
                options: {
                    iterations: number;
                    duration: number;
                    easing: string;
                };
            };
            pulse: {
                kf: {
                    rotate: string[];
                };
                options: {
                    iterations: number;
                    easing: string;
                    duration: number;
                };
            };
            expand: {
                kf: {
                    scale: number[];
                };
                options: {
                    iterations: number;
                    easing: string;
                };
            };
            zoomIn: {
                kf: {
                    scale: number[];
                };
            };
            zoomOut: {
                kf: {
                    scale: number[];
                };
            };
            fadeIn: {
                kf: {
                    opacity: number;
                }[];
                options: {
                    easing: string;
                    fill: string;
                };
            };
            fadeOut: {
                kf: ({
                    opacity: number;
                    visibility?: undefined;
                } | {
                    opacity: number;
                    visibility: string;
                })[];
                options: {
                    easing: string;
                    fill: string;
                };
            };
            shakeX: {
                kf: {
                    translate: (string | number)[];
                };
            };
            shakeY: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutLeft: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInLeft: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutRight: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInRight: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInUp: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInDown: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutUp: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutDown: {
                kf: {
                    translate: (string | number)[];
                };
            };
            wait: {
                kf: {
                    transform: string;
                }[];
                options: {
                    duration: number;
                    iterations: number;
                    easing: string;
                };
            };
            focus: {
                kf: ({
                    offset: number;
                    filter: string;
                } | {
                    filter: string;
                    offset?: undefined;
                })[];
                options: {
                    duration: number;
                };
            };
            spinnerstroke: {
                options: {
                    duration: number;
                    iterations: number;
                    easing: string;
                };
                kf: {
                    offset: number;
                    strokeDashoffset: string;
                    transform: string;
                }[];
            };
        };
        variables: {
            speed: string;
            font: string;
            fontMonospace: string;
            maskOpacity8: number;
            maskOpacity10: number;
            maskOpacity12: number;
            scrollbarWidth: string;
            scrollbarHeight: string;
            scrollbarForeground: string;
        };
        typography: {
            default: {
                fontWeight: number;
                fontFamily: string;
                fontSize: string;
                letterSpacing: string;
            };
            caption: {
                fontSize: string;
                letterSpacing: string;
            };
            h1: {
                fontWeight: number;
                fontSize: string;
                letterSpacing: string;
            };
            h2: {
                fontWeight: number;
                fontSize: string;
                letterSpacing: string;
            };
            h3: {
                fontSize: string;
            };
            h4: {
                fontSize: string;
                letterSpacing: string;
            };
            h5: {
                fontSize: string;
            };
            h6: {
                fontSize: string;
                fontWeight: number;
                letterSpacing: string;
            };
            body2: {
                fontSize: string;
                letterSpacing: string;
            };
            subtitle: {
                letterSpacing: string;
            };
            subtitle2: {
                fontSize: string;
                fontWeight: number;
                letterSpacing: string;
            };
            button: {
                fontSize: string;
                fontWeight: number;
                letterSpacing: string;
                textTransform: string;
            };
            code: {
                fontFamily: string;
                fontSize: string;
            };
        };
        colors: {
            error: RGBA;
            errorOnPrimary: RGBA;
            onError: RGBA;
            warning: RGBA;
            onWarning: RGBA;
            success: RGBA;
            onSuccess: RGBA;
            darkGray: RGBA;
            onDarkGray: RGBA;
            fieldMask: string;
            primaryLight: RGBA;
            onPrimaryLight: RGBA;
            secondaryLight: RGBA;
            onSecondaryLight: RGBA;
            headerText: RGBA;
            onSurface8: RGBA;
            onSurface12: RGBA;
            divider: RGBA;
            shadow: RGBA;
            primary: RGBA;
            onPrimary: RGBA;
            secondary: RGBA;
            onSecondary: RGBA;
            surface: RGBA;
            onSurface: RGBA;
            background: RGBA;
            onBackground: RGBA;
        };
        imports: string[] | undefined;
        globalCss: string;
        global: {
            readonly '@a': {
                readonly color: "primary";
            };
            readonly 'cxl-selection,::selection': {
                readonly backgroundColor: "secondary";
                readonly color: "onSecondary";
            };
            readonly '*': {
                readonly boxSizing: "border-box";
                readonly transition: "opacity var(--cxl-speed), transform var(--cxl-speed), box-shadow var(--cxl-speed), filter var(--cxl-speed), rotate var(--cxl-speed)";
            };
        };
        breakpoints: import("@cxl/ui/css.js").Breakpoints;
        unit: import("@cxl/ui/css.js").CSSUnit;
    }>, selector?: string) => () => HTMLStyleElement, rootStyles: HTMLStyleElement, variable: {
        <K extends "error" | "background" | "shadow" | "errorOnPrimary" | "onError" | "warning" | "onWarning" | "success" | "onSuccess" | "darkGray" | "onDarkGray" | "fieldMask" | "primaryLight" | "onPrimaryLight" | "secondaryLight" | "onSecondaryLight" | "headerText" | "onSurface8" | "onSurface12" | "divider" | "primary" | "secondary" | "onSecondary" | "surface" | "onPrimary" | "onSurface" | "onBackground">(name: K): import("@cxl/ui/css.js").Variable<{
            error: RGBA;
            errorOnPrimary: RGBA;
            onError: RGBA;
            warning: RGBA;
            onWarning: RGBA;
            success: RGBA;
            onSuccess: RGBA;
            darkGray: RGBA;
            onDarkGray: RGBA;
            fieldMask: string;
            primaryLight: RGBA;
            onPrimaryLight: RGBA;
            secondaryLight: RGBA;
            onSecondaryLight: RGBA;
            headerText: RGBA;
            onSurface8: RGBA;
            onSurface12: RGBA;
            divider: RGBA;
            shadow: RGBA;
            primary: RGBA;
            onPrimary: RGBA;
            secondary: RGBA;
            onSecondary: RGBA;
            surface: RGBA;
            onSurface: RGBA;
            background: RGBA;
            onBackground: RGBA;
        }[K]>;
        <K extends "font" | "scrollbarWidth" | "speed" | "fontMonospace" | "maskOpacity8" | "maskOpacity10" | "maskOpacity12" | "scrollbarHeight" | "scrollbarForeground">(name: K): import("@cxl/ui/css.js").Variable<{
            speed: string;
            font: string;
            fontMonospace: string;
            maskOpacity8: number;
            maskOpacity10: number;
            maskOpacity12: number;
            scrollbarWidth: string;
            scrollbarHeight: string;
            scrollbarForeground: string;
        }[K]>;
    };
    const globalCssSymbol: unique symbol;
    global {
        interface Node {
            [globalCssSymbol]?: boolean;
        }
    }
    export type Spacing = ArrayElement<typeof SpacingValues>;
    export const SpacingValues: readonly [0, 4, 8, 16, 24, 32, 48, 64];
    export const FocusCircleStyle: () => HTMLStyleElement;
    export function loadTheme(name: string, key: string): void;
    export function spacingCss(fn: (val: Spacing) => Styles): Styles;
    export function observeTheme(host: Component): import("@cxl/ui/rx.js").Observable<(PartialTheme & {
        css: string;
        name: string;
    }) | undefined, "none">;
    export function css(styles: Styles): (host: Component) => HTMLStyleElement;
    type DerivedColors = ReturnType<typeof getDerivedColors>;
    function getDerivedColors(b: BaseColors): {
        error: RGBA;
        errorOnPrimary: RGBA;
        onError: RGBA;
        warning: RGBA;
        onWarning: RGBA;
        success: RGBA;
        onSuccess: RGBA;
        darkGray: RGBA;
        onDarkGray: RGBA;
        fieldMask: string;
        primaryLight: RGBA;
        onPrimaryLight: RGBA;
        secondaryLight: RGBA;
        onSecondaryLight: RGBA;
        headerText: RGBA;
        onSurface8: RGBA;
        onSurface12: RGBA;
        divider: RGBA;
        shadow: RGBA;
    };
    export function buildPalette(colors: BaseColors, derived?: Partial<DerivedColors>): {
        error: RGBA;
        errorOnPrimary: RGBA;
        onError: RGBA;
        warning: RGBA;
        onWarning: RGBA;
        success: RGBA;
        onSuccess: RGBA;
        darkGray: RGBA;
        onDarkGray: RGBA;
        fieldMask: string;
        primaryLight: RGBA;
        onPrimaryLight: RGBA;
        secondaryLight: RGBA;
        onSecondaryLight: RGBA;
        headerText: RGBA;
        onSurface8: RGBA;
        onSurface12: RGBA;
        divider: RGBA;
        shadow: RGBA;
        primary: RGBA;
        onPrimary: RGBA;
        secondary: RGBA;
        onSecondary: RGBA;
        surface: RGBA;
        onSurface: RGBA;
        background: RGBA;
        onBackground: RGBA;
    };
    const surfaceColors: readonly ["background", "primary", "primaryLight", "secondary", "surface", "error", "success", "warning", "darkGray"];
    export const SurfaceColorNames: string[];
    export function applyColorFromString(color: string): string;
    export const ColorStyles: Record<SurfaceColorValue, StyleDef>;
    export const OutlineColorStyles: (prefix?: string) => Record<string, StyleDef>;
    export function FlatColorStyles(prefix: string): Record<string, StyleDef>;
    export type MaskType = keyof typeof mask;
    const mask: {
        black8: RGBA;
        black12: RGBA;
    };
    export function bgMask(backgroundColor: Color<UiTheme>, maskType: MaskType): {
        backgroundColor: Color<{
            animation: {
                none: undefined;
                flash: {
                    kf: {
                        opacity: number[];
                    };
                    options: {
                        iterations: number;
                        easing: string;
                    };
                };
                spin: {
                    kf: {
                        rotate: string[];
                    };
                    options: {
                        iterations: number;
                        duration: number;
                        easing: string;
                    };
                };
                pulse: {
                    kf: {
                        rotate: string[];
                    };
                    options: {
                        iterations: number;
                        easing: string;
                        duration: number;
                    };
                };
                expand: {
                    kf: {
                        scale: number[];
                    };
                    options: {
                        iterations: number;
                        easing: string;
                    };
                };
                zoomIn: {
                    kf: {
                        scale: number[];
                    };
                };
                zoomOut: {
                    kf: {
                        scale: number[];
                    };
                };
                fadeIn: {
                    kf: {
                        opacity: number;
                    }[];
                    options: {
                        easing: string;
                        fill: string;
                    };
                };
                fadeOut: {
                    kf: ({
                        opacity: number;
                        visibility?: undefined;
                    } | {
                        opacity: number;
                        visibility: string;
                    })[];
                    options: {
                        easing: string;
                        fill: string;
                    };
                };
                shakeX: {
                    kf: {
                        translate: (string | number)[];
                    };
                };
                shakeY: {
                    kf: {
                        translate: (string | number)[];
                    };
                };
                slideOutLeft: {
                    kf: {
                        translate: (string | number)[];
                    };
                };
                slideInLeft: {
                    kf: {
                        translate: (string | number)[];
                    };
                };
                slideOutRight: {
                    kf: {
                        translate: (string | number)[];
                    };
                };
                slideInRight: {
                    kf: {
                        translate: (string | number)[];
                    };
                };
                slideInUp: {
                    kf: {
                        translate: (string | number)[];
                    };
                };
                slideInDown: {
                    kf: {
                        translate: (string | number)[];
                    };
                };
                slideOutUp: {
                    kf: {
                        translate: (string | number)[];
                    };
                };
                slideOutDown: {
                    kf: {
                        translate: (string | number)[];
                    };
                };
                wait: {
                    kf: {
                        transform: string;
                    }[];
                    options: {
                        duration: number;
                        iterations: number;
                        easing: string;
                    };
                };
                focus: {
                    kf: ({
                        offset: number;
                        filter: string;
                    } | {
                        filter: string;
                        offset?: undefined;
                    })[];
                    options: {
                        duration: number;
                    };
                };
                spinnerstroke: {
                    options: {
                        duration: number;
                        iterations: number;
                        easing: string;
                    };
                    kf: {
                        offset: number;
                        strokeDashoffset: string;
                        transform: string;
                    }[];
                };
            };
            variables: {
                speed: string;
                font: string;
                fontMonospace: string;
                maskOpacity8: number;
                maskOpacity10: number;
                maskOpacity12: number;
                scrollbarWidth: string;
                scrollbarHeight: string;
                scrollbarForeground: string;
            };
            typography: {
                default: {
                    fontWeight: number;
                    fontFamily: string;
                    fontSize: string;
                    letterSpacing: string;
                };
                caption: {
                    fontSize: string;
                    letterSpacing: string;
                };
                h1: {
                    fontWeight: number;
                    fontSize: string;
                    letterSpacing: string;
                };
                h2: {
                    fontWeight: number;
                    fontSize: string;
                    letterSpacing: string;
                };
                h3: {
                    fontSize: string;
                };
                h4: {
                    fontSize: string;
                    letterSpacing: string;
                };
                h5: {
                    fontSize: string;
                };
                h6: {
                    fontSize: string;
                    fontWeight: number;
                    letterSpacing: string;
                };
                body2: {
                    fontSize: string;
                    letterSpacing: string;
                };
                subtitle: {
                    letterSpacing: string;
                };
                subtitle2: {
                    fontSize: string;
                    fontWeight: number;
                    letterSpacing: string;
                };
                button: {
                    fontSize: string;
                    fontWeight: number;
                    letterSpacing: string;
                    textTransform: string;
                };
                code: {
                    fontFamily: string;
                    fontSize: string;
                };
            };
            colors: {
                error: RGBA;
                errorOnPrimary: RGBA;
                onError: RGBA;
                warning: RGBA;
                onWarning: RGBA;
                success: RGBA;
                onSuccess: RGBA;
                darkGray: RGBA;
                onDarkGray: RGBA;
                fieldMask: string;
                primaryLight: RGBA;
                onPrimaryLight: RGBA;
                secondaryLight: RGBA;
                onSecondaryLight: RGBA;
                headerText: RGBA;
                onSurface8: RGBA;
                onSurface12: RGBA;
                divider: RGBA;
                shadow: RGBA;
                primary: RGBA;
                onPrimary: RGBA;
                secondary: RGBA;
                onSecondary: RGBA;
                surface: RGBA;
                onSurface: RGBA;
                background: RGBA;
                onBackground: RGBA;
            };
            imports: string[] | undefined;
            globalCss: string;
            global: {
                readonly '@a': {
                    readonly color: "primary";
                };
                readonly 'cxl-selection,::selection': {
                    readonly backgroundColor: "secondary";
                    readonly color: "onSecondary";
                };
                readonly '*': {
                    readonly boxSizing: "border-box";
                    readonly transition: "opacity var(--cxl-speed), transform var(--cxl-speed), box-shadow var(--cxl-speed), filter var(--cxl-speed), rotate var(--cxl-speed)";
                };
            };
            breakpoints: import("@cxl/ui/css.js").Breakpoints;
            unit: import("@cxl/ui/css.js").CSSUnit;
        }>;
        backgroundImage: string;
    };
    export const DisabledStyles: {
        cursor: string;
        filter: string;
        opacity: number;
        pointerEvents: string;
    };
    export const StateStyles: {
        $focus: {
            outline: number;
        };
        $disabled: {
            cursor: string;
            filter: string;
            opacity: number;
            pointerEvents: string;
        };
    };
    export function scrollbarStyles(prefix?: string): {
        [x: string]: {
            width: string;
            height: string;
            background?: undefined;
        } | {
            background: string;
            width?: undefined;
            height?: undefined;
        };
    };
    export function delayTheme(): void;
    export function buildIconFactoryCdn(getUrl: (id: string, width?: number) => string): (id: string, width?: number) => Node;
    /**
     * By default we use the material icons CDN to retrieve icon svg files.
     */
    export const iconFactoryCdn: (id: string, width?: number) => Node;
    export function registerDefaultIconFactory(fn: (id: string) => Node): void;
    export function registerIcon(icon: IconDef): void;
    export function getColorStyles(color: SurfaceColorValue): {
        color: string;
        backgroundColor: string;
    };
    export function getIcon(id: string, prop?: SvgIconAttributes): SVGSVGElement;
}
/// <amd-module name="@cxl/ui/core.js" />
declare module "@cxl/ui/core.js" {
    import { AttributeEvent, Component, ComponentAttributeName } from "@cxl/ui/component.js";
    import { Observable, Operator } from "@cxl/ui/rx.js";
    import { BreakpointKey, StyleDefinition } from "@cxl/ui/css.js";
    import { CustomEventMap } from "@cxl/ui/dom.js";
    import "@cxl/ui/template.js";
    import { SurfaceColorValue, Styles } from "@cxl/ui/theme.js";
    module "@cxl/ui/rx.js" {
        interface Observable<T> {
            is(equalTo: T): Observable<boolean>;
            log(): Observable<T>;
            raf(fn?: (val: T) => void): Observable<T>;
        }
    }
    export type ArrayElement<ArrayType extends readonly unknown[]> = ArrayType extends readonly (infer ElementType)[] ? ElementType : never;
    export type Size = ArrayElement<typeof SizeValues>;
    export interface ElementWithValue<T> extends HTMLElement {
        value: T;
    }
    export const SizeValues: readonly [-2, -1, 0, 1, 2, 3, 4, 5, "small", "big"];
    export const FocusMask: {
        readonly mask: {
            readonly position: "absolute";
            readonly left: 0;
            readonly right: 0;
            readonly bottom: 0;
            readonly top: 0;
            readonly backgroundColor: "onSurface";
            readonly opacity: 0;
        };
        readonly mask$hover: {
            readonly opacity: import("@cxl/ui/css.js").Variable<number>;
        };
        readonly mask$focusVisible: {
            readonly opacity: import("@cxl/ui/css.js").Variable<number>;
        };
    };
    export const maskStyles: () => HTMLStyleElement;
    export function is<T>(equalTo: T): (source: Observable<T, "none">) => Observable<boolean, "none">;
    export function log<T>(): Operator<T>;
    export function getAttribute<T extends Node, K extends ComponentAttributeName<T>>(el: T, name: K): Observable<T[K], "none">;
    export function displayContents(): Node;
    export function changeEvent(host: Component & {
        value: unknown;
    }): Observable<unknown, "none">;
    export function mask(): HTMLElement;
    export function persistWithParameter(prefix: string): Operator<AttributeEvent<Component>, AttributeEvent<Component>>;
    export function getTarget<T extends Component, K extends ComponentAttributeName<T>>(host: T, prop: K): Observable<Exclude<T[K], string>, "none">;
    export function PrefixAttribute(prefix: string): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
    export function NumberAttribute(min?: number, max?: number): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
    export function SizeAttribute(fn: (size: Exclude<Size, 'small' | 'big'>) => Record<string, StyleDefinition>): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
    export function ForegroundColorAttribute(defaultColor?: SurfaceColorValue): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
    export function ColorAttribute(defaultColor?: SurfaceColorValue): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
    export function CssAttribute(styles: Styles): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
    export function breakpoint(el: HTMLElement): Observable<BreakpointKey>;
    export function breakpointClass(el: HTMLElement): Observable<string, "none">;
    type VoidEvent = {
        [K in keyof CustomEventMap]: CustomEventMap[K] extends void ? K : never;
    }[keyof CustomEventMap];
    export function message<K extends VoidEvent>(el: EventTarget, event: K): void;
    export function message<K extends keyof CustomEventMap>(el: EventTarget, event: K, detail: CustomEventMap[K]): void;
    export function onMessage<K extends keyof CustomEventMap>(el: EventTarget, event: K, stopPropagation?: boolean): Observable<CustomEventMap[K]>;
}
/// <amd-module name="@cxl/ui/a11y.js" />
declare module "@cxl/ui/a11y.js" {
    import { Observable } from "@cxl/ui/rx.js";
    import type { Component } from "@cxl/ui/component.js";
    type AriaProperties = {
        atomic: string;
        autocomplete: string;
        busy: string;
        checked: string;
        controls: string;
        current: string;
        describedby: string;
        details: string;
        disabled: string;
        dropeffect: string;
        errormessage: string;
        expanded: string;
        flowto: string;
        grabbed: string;
        haspopup: string;
        hidden: string;
        invalid: string;
        keyshortcuts: string;
        label: string;
        labelledby: string;
        level: string;
        live: string;
        orientation: string;
        owns: string;
        placeholder: string;
        pressed: string;
        readonly: string;
        required: string;
        selected: string;
        sort: string;
        valuemax: string;
        valuemin: string;
        valuenow: string;
        valuetext: string;
        modal: string;
        multiline: string;
        multiselectable: string;
        relevant: string;
        roledescription: string;
    };
    type AriaProperty = keyof AriaProperties;
    export type AriaAttributeName = `aria-${AriaProperty}`;
    /**
     * Sets an ARIA property on a component.
     * @param prop The ARIA property name (e.g., "checked", "modal").
     * @param value The value to set for the property.
     * @returns An Observable that sets the attribute on the component.
     */
    export function aria<T extends Component>(prop: AriaProperty, value: string): (ctx: T) => Observable<unknown, "none">;
    /**
     * Sets the value of an ARIA property on an HTML element.
     * Handles boolean and undefined values for specific properties.
     * @param host The target element.
     * @param prop The ARIA property name.
     * @returns An Observable that sets the attribute on the element.
     */
    export function ariaValue(host: Element, prop: AriaProperty): import("@cxl/ui/rx.js").Operator<string | number | boolean, string | number | boolean>;
    /**
     * Specialized function to set the "aria-checked" state of an element
     * Handles boolean and undefined values appropriately for mixed states
     */
    export function ariaChecked(host: Element): import("@cxl/ui/rx.js").Operator<boolean | undefined, boolean | undefined>;
    /**
     * Function to set the ARIA role of a component
     */
    export function role<T extends Component>(roleName: string): (ctx: T) => Observable<unknown, "none">;
    export function ariaDescribed(target: Element, by: Element): Observable<string, "none">;
    /**
     * Sets the aria-label on a target element based on changes to a source element's attributes.
     * Considers inline content ("title" or "aria-label") and referenced elements ("aria-labelledby").
     * @param source The source element to monitor for attribute changes.
     * @param target The target element to set the aria-label on.
     * @param text An optional Observable that provides additional text for the aria-label.
     * @returns An Observable that manages the aria-label updates.
     */
    export function ariaLabelOrDefault(source: HTMLElement, target: HTMLElement, text?: Observable<string>): Observable<string, "none">;
    /**
     * Apply aria label only if not specified
     */
    export function ariaLabel(text: Observable<string>): (el: HTMLElement) => Observable<string, "none">;
    export function getAriaId(el: Element): Observable<string, "none">;
}
/// <amd-module name="@cxl/ui/amd.js" />
declare var require: {
    replace?: (p: string) => string;
    href?: string;
};
/// <amd-module name="@cxl/ui/focusable.js" />
declare module "@cxl/ui/focusable.js" {
    import { Component } from "@cxl/ui/component.js";
    module "@cxl/ui/dom.js" {
        interface CustomEventMap {
            'focusable.change': void;
        }
    }
    interface DisableElement extends HTMLElement {
        disabled: boolean;
    }
    export interface FocusableComponent extends Component {
        disabled: boolean;
        touched: boolean;
    }
    export const stateStyles: () => HTMLStyleElement;
    export function disabledAttribute(host: Component & {
        disabled: boolean;
    }): import("@cxl/ui/rx.js").Observable<boolean, "none">;
    export function focusableEvents<T extends FocusableComponent>(host: T, element?: HTMLElement): import("@cxl/ui/rx.js").Observable<FocusEvent | T["disabled"] | T["touched"], "none">;
    export function focusableDisabled<T extends FocusableComponent>(host: T, element?: HTMLElement): import("@cxl/ui/rx.js").Observable<boolean, "none">;
    export function focusable<T extends FocusableComponent>(host: T, element?: HTMLElement): import("@cxl/ui/rx.js").Observable<boolean | FocusEvent | T["disabled"] | T["touched"], "none">;
    export function focusDelegate<T extends FocusableComponent>(host: T, delegate: DisableElement): import("@cxl/ui/rx.js").Observable<boolean | FocusEvent | T["disabled"] | T["touched"], "none">;
    /**
     * Adds focusable functionality to input components.
     */
    export function Focusable(host: FocusableComponent): HTMLStyleElement;
}
/// <amd-module name="@cxl/ui/ripple.js" />
declare module "@cxl/ui/ripple.js" {
    import { Component } from "@cxl/ui/component.js";
    export function attachRipple<T extends HTMLElement>(hostEl: T, ev: MouseEvent | KeyboardEvent): void;
    /**
     * Attaches a ripple element (cxl-ripple) to a host element upon a mouse or keyboard event.
     * Positions the ripple element based on the event coordinates.
     */
    export function ripple(element: HTMLElement & {
        disabled?: boolean;
    }): import("@cxl/ui/rx.js").Observable<MouseEvent, "none">;
    /**
     * The Ripple component adds a visual ripple effect to clickable elements,
     * enhancing user experience by providing clear feedback upon interaction.
     */
    export class Ripple extends Component {
        /** Controls the horizontal position of the ripple effect's origin */
        x: number;
        /** Controls the vertical position of the ripple effect's origin. */
        y: number;
        /** Determines the size of the ripple wave.*/
        radius: number;
    }
    /**
     * A container element for clickable elements with ripple effects.
     * Handles ripple attachment using the ripple function. Provides basic styling for containing ripple elements.
     *
     * @example
     * <cxl-ripple-container style="border:1px solid #000;padding:16px" ><cxl-t font="h3" center>Click Me</cxl-t></cxl-ripple-container>
     */
    export class RippleContainer extends Component {
    }
}
