import { Component } from './component.js';
import { AnimationKey, UiTheme } from './theme.js';
import { Observable } from './rx.js';
import { AnimationDefinition } from './css.js';
/**
 * Interface for options used with the `animate` function.
 */
export interface AnimateOptions {
    target: Element;
    animation: AnimationKey | AnimationDefinition;
    options?: KeyframeAnimationOptions;
}
/**
 * Interface for animation events emitted by the `animation` function.
 */
export interface AnimationEvent {
    type: 'start' | 'end';
    /** Animation object associated with the event. */
    animation: Animation;
}
type A = keyof UiTheme['animation'];
export type AnimationList = A | `${A} ${A}` | `${A} ${A} ${A}`;
/**
 * Function to create a CSS animation on a target element.
 *
 * @param options - Animation options including target element, animation name, and additional options.
 * @throws Error if the specified animation is not defined in the theme.
 * @returns Animation object representing the created animation.
 */
export declare function animate({ target, animation, options }: AnimateOptions): Animation;
/**
 * Function to create an observable that emits events when an animation starts and ends.
 *
 * @param options Options for the animation. Specifies the target element, animation key or definition, optional animation settings, and trigger type.
 * @returns Observable that emits AnimationEvent objects.
 */
export declare function animation(options: AnimateOptions & {
    trigger?: 'visible' | 'hover';
}): Observable<AnimationEvent, "none">;
/**
 * The Animate component allows you to add CSS animations to your UI elements and control their behavior.
 *
 * @beta
 *
 * @example
 * <cxl-animate style="margin-top: 32px" name="spin"><cxl-t>Animate</cxl-t></cxl-animate>
 */
export declare class Animate extends Component {
    /**
     * Defines the animation(s) to apply. It can be a single animation name from the theme
     * or a space-separated list of animations. The special value 'none' prevents any animation.
     */
    name?: AnimationList;
    /** Sets the delay in milliseconds before the animation starts. */
    delay?: number;
    /** Sets the delay in milliseconds after the animation finishes before it is removed. */
    enddelay?: number;
    /**
     * Defines the trigger for the animation.
     *
     * When set to `visible`, the animation will start when the element becomes visible and pause when it becomes hidden.
     *
     * If set to `hover`, the animation will start when the element is hovered over and stop when the hover ends.
     *
     * @example
     * <cxl-animate style="margin-top: 32px" name="spin" trigger="hover"><cxl-t>Animate</cxl-t></cxl-animate>
     *
     */
    trigger?: 'visible' | 'hover';
    /** Sets the animation duration in milliseconds. */
    duration?: number;
    /** Defines the number of times the animation should repeat. Set to 'infinite' for continuous animation. */
    iterations?: number | 'infinite';
    /** Defines the animation timing function, such as 'ease', 'linear', or a cubic-bezier function. */
    easing?: string;
}
export {};
