import { Component } from './component.js';
import { Size } from './core.js';
import { FocusableComponent } from './focusable.js';
import { SurfaceColorValue } from './theme.js';
export declare function buttonKeyboardBehavior(host: Component & {
    disabled: boolean;
}): import("./rx.js").Observable<KeyboardEvent, "none">;
export declare function buttonBehavior(host: FocusableComponent): import("./rx.js").Observable<boolean | FocusEvent | KeyboardEvent, "none">;
export declare function focusableButton(host: FocusableComponent): HTMLStyleElement;
export declare function focusableButtonWithRipple(host: FocusableComponent): Node;
export declare class ButtonHeadless extends Component {
    /**
     * When set to true, disables the button interaction and applies a disabled visual style.
     */
    disabled: boolean;
    /**
     * Sets the color of the button. This applies to both the button text and the ripple effect.
     */
    color?: SurfaceColorValue;
    /**
     * This attribute sets a visual state indicating the button has been interacted with.
     */
    touched: boolean;
}
/**
 * The ButtonBase component serves as the foundation for various button types.
 * It provides a core set of styles, behaviors, and interaction logic, which can be extended
 * by other button components to offer more specific appearances and functionalities.
 */
export declare class ButtonBase extends ButtonHeadless {
    /**
     * When set to true, applies a flat button style without elevation or borders.
     *
     * @deprecated Use <cxl-button-flat>
     * @demo
       <cxl-toolbar>
            <cxl-button flat size="-1">Small</cxl-button>
            <cxl-button flat size="0">Size 0</cxl-button>
            <cxl-button flat size="1">Size 1</cxl-button>
            <cxl-button flat size="2">Size 2</cxl-button>
       </cxl-toolbar>
     */
    flat: boolean;
    /**
     * Applies the outline style
     * @deprecated Use <cxl-button-outline>
     */
    outline: boolean;
}
/**
 * The Button component builds upon the ButtonBase class to provide a standard button style with customizable size
 * and optional vertical layout. It offers a versatile button option for various UI elements in your application.
 *
 * @example
 * <cxl-toolbar>
 *   <cxl-button color="primary">Primary</cxl-button>
 *   <cxl-button flat>Flat</cxl-button>
 *   <cxl-button color="secondary" outline>Outlined</cxl-button>
 * </cxl-toolbar>
 * @demo <caption>Colors</caption>
 * <cxl-toolbar>
    <cxl-button>Button</cxl-button>
    <cxl-button color="primary">Primary</cxl-button>
    <cxl-button color="secondary">Secondary</cxl-button>
    <cxl-button color="error">Error</cxl-button>
    <cxl-button color="success">Success</cxl-button>
    <cxl-button color="warning">Warning</cxl-button>
</cxl-toolbar>
 * @demo <caption>Flat</caption>
 * <cxl-toolbar>
    <cxl-button flat>Button</cxl-button>
    <cxl-button flat color="primary">Primary</cxl-button>
    <cxl-button flat color="secondary">Secondary</cxl-button>
    <cxl-button flat color="error">Error</cxl-button>
    <cxl-button flat color="success">Success</cxl-button>
    <cxl-button flat color="warning">Warning</cxl-button>
</cxl-toolbar>
 * @demo <caption>Outline</caption>
 * <cxl-toolbar>
    <cxl-button outline>Button</cxl-button>
    <cxl-button outline color="primary">Primary</cxl-button>
    <cxl-button outline color="secondary">Secondary</cxl-button>
    <cxl-button outline color="error">Error</cxl-button>
    <cxl-button outline color="success">Success</cxl-button>
    <cxl-button outline color="warning">Warning</cxl-button>
</cxl-toolbar>
 * @demo <caption>Disabled</caption>
 * <cxl-toolbar>
    <cxl-button disabled>Button</cxl-button>
    <cxl-button disabled color="primary">Primary</cxl-button>
    <cxl-button disabled outline color="secondary">Secondary</cxl-button>
    <cxl-button disabled flat color="error">Error</cxl-button>
</cxl-toolbar>
 * @demo <caption>Size</caption>
 * <cxl-toolbar>
    <cxl-button size="-1">Button</cxl-button>
    <cxl-button size="0" color="primary">Primary</cxl-button>
    <cxl-button size="1" outline color="secondary">Secondary</cxl-button>
    <cxl-button size="2" flat color="error">Error</cxl-button>
    <cxl-button size="3" outline color="success">Success</cxl-button>
    <cxl-button size="4" color="warning">Warning</cxl-button>
</cxl-toolbar>
 * @demo <caption>With Icon</caption>
<cxl-toolbar>
    <cxl-button><cxl-icon name="help"></cxl-icon> Help</cxl-button>
    <cxl-button color="primary"><cxl-icon name="help"></cxl-icon> Help</cxl-button>
    <cxl-button flat><cxl-icon name="help"></cxl-icon> Help</cxl-button>
    <cxl-button outline color="secondary"><cxl-icon name="help"></cxl-icon> Help</cxl-button>
</cxl-toolbar>
 */
export declare class Button extends ButtonBase {
    /** Controls the size of the button. */
    size: Size;
    /**
     * @example
     * <cxl-button vflex>
     *   <cxl-icon name="contacts"></cxl-icon>
     *   Contacts
     * </cxl-button>
     */
    vflex: boolean;
}
export declare const iconButtonCss: (host: Component) => HTMLStyleElement;
/**
 * This component renders a round-shaped button
 * @beta
 * @example
 * <cxl-toolbar>
 * <cxl-button-round aria-label="search"><cxl-icon name="search"></cxl-icon></cxl-button-round>
 * <cxl-button-round color="primary"><cxl-icon name="notifications" width="48"></cxl-icon></cxl-button>
 * </cxl-toolbar>
 */
export declare class ButtonRound extends ButtonBase {
}
