import { Component } from './component.js';
import { Navigation } from './navigation.js';
declare module './registable.js' {
    interface RegistableMap {
        dataset: DatasetController;
        'dataset.record': DatasetRecordController;
        'dataset.recordhost': DatasetRecordHostController;
    }
}
type SortFunction<T> = (a: T, b: T, dir: 1 | -1) => number;
/**
 * This type defines the structure of an object used for dataset requests.
 */
export type DatasetRequest = {
    /** This property references the Dataset component that initiated the data request. */
    state: Dataset;
    /** This property holds the data associated with the request. It can be either an array of data records or a promise that resolves to an array of data records. */
    data?: Promise<unknown[]> | unknown[];
};
export type DatasetController = (event: DatasetEvent) => void;
export type DatasetRecordHostController = DatasetRecordController & {
    node: Node;
};
export type DatasetRecord = Record<string, unknown>;
export type DatasetEvent<T extends Dataset = Dataset, RecordT extends DatasetRecord = DatasetRecord> = {
    target: T;
} & ({
    type: 'connect' | 'disconnect';
} | {
    type: 'render';
    value: RecordT[];
});
export type DatasetRecordController = (action: DatasetRecordEvent) => void;
export type DatasetRecordEvent = {
    target: EventTarget;
    dataset?: Dataset;
} & ({
    type: 'render';
    record: DatasetRecord | undefined;
} | {
    type: 'connect' | 'disconnect';
});
interface SortableElement extends Component, SortState {
    multiple: boolean;
}
export interface FilterState {
    field?: string;
    term: unknown;
    type: 'exact' | 'contains' | 'containsCaseSensitive';
    getter?: (v: unknown) => boolean;
}
export type SortState = {
    field?: string;
    method?: 'text' | 'numeric' | SortFunction<unknown>;
    sort?: 'asc' | 'desc' | 'none' | '' | boolean;
};
export interface DatasetState {
    sort?: SortState[];
    slice?: {
        page: number;
        rows: number;
    };
    filter?: ((a: DatasetRecord) => boolean) | FilterState;
    filteredLength?: number;
}
export type DatasetSource = DatasetRecord[] | ((state: DatasetState) => DatasetRecord[] | Promise<DatasetRecord[]>);
export declare function datasetSelectable<T extends Component>(host: Component, el: T, prop: keyof T): import("./rx.js").Observable<Event, "none">;
/**
 * The cxl-dataset-selected-count component displays the number of currently selected rows within a dataset.
 * It provides a visual indication of how many data items are selected at any given time.
 *
 * Typical Uses:
 * - Implementing selection summaries within data tables.
 * - Providing feedback on the number of chosen options in multi-select functionalities.
 * - Keeping track of selected items in dataset-driven UIs.
 *
 * @see Dataset
 * @demo
<cxl-dataset id="dataSet">
    <cxl-toolbar dense>
        Count: <cxl-dataset-selected-count></cxl-dataset-selected-count>
    </cxl-toolbar>
    <cxl-each-record>
        <template>
            <cxl-dataset-select checked>
                <cxl-bind $text="name"></cxl-bind>,
                <cxl-bind $text="color"></cxl-bind>
            </cxl-dataset-select>
        </template>
    </cxl-each-record>
</cxl-dataset>
<script>
    dataSet.source = [
        { "name": "Apple", "color": "red" },
        { "name": "Orange", "color": "green" },
        { "name": "Apple", "color": "green" },
    ];
</script>
 */
export declare class DatasetSelectedCount extends Component {
}
export declare function datasetRegistable<T extends Dataset = Dataset>(host: Component): import("./rx.js").Observable<DatasetEvent<T, DatasetRecord> | {
    type: "update";
    target: T;
}, "none">;
export declare function datasetRecordHost(host: Component & {
    source?: DatasetRecord;
}): import("./rx.js").Observable<DatasetRecordEvent, "none">;
/**
 * The DatasetRecord component acts as a container element for components that need access
 * to a specific data record from a dataset. It establishes a connection between the component
 * and the dataset, facilitating data flow and rendering updates based on the selected record.
 *
 * Typical Uses:
 * - Creating templates for individual data items within a dataset.
 * - Building components that display or interact with specific dataset records.
 *
 * The DatasetRecord component itself doesn't expose the data record directly.
 * However, child components can subscribe to the observable stream provided by datasetRecordHost
 * to receive data update events containing the relevant record.
 *
 */
export declare class DatasetRecordComponent extends Component {
    /**
     * This optional property allows you to define a data record directly within the component.
     */
    source?: DatasetRecord;
}
export declare function templateHost($: Component & {
    templateid?: string;
    wrap?: (el: Node) => Element;
}): import("./rx.js").Observable<never, "none">;
/**
 * The Each component facilitates the creation of dynamic content based on an array of data from a dataset.
 * It leverages templates to define the structure and content for each data item.
 *
 * Typical Uses:
 * - Rendering lists of items based on a dataset.
 * - Creating data tables with rows populated from dataset records.
 * - Dynamically generating content sections based on data variations.
 *
 * The Each component utilizes the `templateHost` function to manage template handling and data updates.
 * It can either reference a template using the `templateid` attribute or directly embed a template element
 * as its first child. When the data source (dataset) emits a `render` event, the Each component adjusts
 * the number of rendered elements based on the data array length.
 * It clones the template content for each data item and appends it to the `Each` component's content area.
 *
 * @beta
 */
export declare class Each extends Component {
    /**
     * Specifies the ID of a template element to be used for rendering each data item.
     */
    templateid?: string;
}
/**
 * The EachRecord component iterates through the active dataset and renders each data item
 * using a `cxl-dataset-record` component. This simplifies the process of creating individual
 * components for each dataset record and automatically establishes the necessary connection
 * for data access within those components.
 *
 * The `EachRecord` component inherits functionality from the `Each` component.
 * It leverages the `templateHost` function to handle template management and data updates.
 * However, it overrides the default wrapping behavior of Each. When rendering each data item,
 * it creates a new `cxl-dataset-record` component, appends the cloned template content to it,
 * and returns the `cxl-dataset-record` element. This automatically connects child components
 * within the template to the corresponding data record.
 *
 * @beta
 */
export declare class EachRecord extends Each {
    wrap(node: Node): Component;
}
export declare class DatasetTemplate extends Component {
    templateid?: string;
}
export declare function textSort(a: unknown, b: unknown, dir?: number): number;
export declare function numericSort(a: unknown, b: unknown, dir?: number): number;
export declare function applyDataset(state: DatasetState, source: DatasetRecord[]): DatasetRecord[];
export declare function datasetSortable($: SortableElement): import("./rx.js").Observable<DatasetEvent<Dataset, DatasetRecord> | {
    type: "update";
    target: Dataset;
}, "none">;
export declare function getPageCount(total: number, rows: number): number;
/**
 * The DatasetNavigation component provides navigation controls for a Dataset component.
 * It allows users to navigate through large datasets by managing the displayed page and number of rows per page.
 *
 * @see Dataset
 *
 * @demo
<cxl-dataset id="dataSet">
    <cxl-each-record>
        <template>
            <cxl-chip>
                <cxl-bind $text="name"></cxl-bind>,
                <cxl-bind $text="color"></cxl-bind>
            </cxl-chip>
        </template>
    </cxl-each-record>
    <cxl-toolbar>
        <cxl-dataset-navigation></cxl-dataset-navigation>
        <cxl-dataset-pagination-text style="margin-left:auto"></cxl-dataset-pagination-text>
    </cxl-toolbar>
</cxl-dataset>
<script>
    dataSet.source = [
        { "name": "Apple", "color": "red" },
        { "name": "Orange", "color": "green" },
        { "name": "Apple", "color": "green" },
        { "name": "Raspberry", "color": "red" },
        { "name": "Blueberry", "color": "blue" }
    ];
</script>
 */
export declare class DatasetNavigation extends Navigation {
    datasetElement?: Dataset;
    /** The number of rows to display per page */
    rows: number;
}
export declare function paginationText($: Component): import("./rx.js").Observable<string, "none">;
/**
 * The DatasetPaginationText component displays a textual representation of the current page
 * and data range within a Dataset. It provides users with information on which items they are
 * viewing and the total number of items available.
 *
 * Typical Uses:
 * - Implementing clear pagination indicators within data tables.
 * - Informing users about their position and progress while navigating through a dataset.
 *
 * @see DatasetNavigation
 */
export declare class DatasetPaginationText extends Component {
}
/**
 * The DatasetEmpty component acts as a placeholder element that automatically controls its visibility
 * based on the emptiness of a Dataset. It provides a way to display custom content when there is no
 * data available in the dataset.
 *
 * Typical Uses:
 * - Implementing informative messages or visuals for empty datasets.
 * - Enhancing the user experience by providing feedback in the absence of data.
 * - Creating a clear distinction between empty and populated dataset states.
 *
 * @demo
<cxl-dataset id="dataSet">
    <cxl-c vpad="8">
        <cxl-toolbar>
            <cxl-field dense outline style="flex-grow: 1">
                <cxl-label>Search</cxl-label>
                <cxl-input id="search" value="Banana"></cxl-input>
            </cxl-field>
        </cxl-toolbar>
        <cxl-dataset-empty>
            <cxl-c pad="16" center>
                No Results Found
            </cxl-c>
        </cxl-dataset-empty>
        <cxl-each-record>
            <template>
                <cxl-c pad="16">
                    <cxl-bind $text="name"></cxl-bind>,
                    <cxl-bind $text="color"></cxl-bind>
                </cxl-c>
            </template>
        </cxl-each-record>
    </cxl-c>
</cxl-dataset>
<script>
    dataSet.source = [
        { "name": "Apple", "color": "red" },
        { "name": "Orange", "color": "green" },
        { "name": "Apple", "color": "green" },
        { "name": "Raspberry", "color": "red" },
        { "name": "Blueberry", "color": "blue" }
    ];
    const update = search.onchange = () => { dataSet.filter = { term: search.value } }
    update();
</script>
 */
export declare class DatasetEmpty extends Component {
}
/**
 * This abstract class provides the foundation for components that manage datasets and render them visually.
 * It handles data source interactions, record updates, selection management, and triggering rendering based on changes.
 */
export declare abstract class DatasetBase extends Component {
    /**
     * This optional property specifies a data source that can be an array of data or a function that retrieves data asynchronously.
     */
    source?: DatasetSource;
    /**
     * This property holds the current dataset as an array of records.
     */
    value: DatasetRecord[];
    /**
     * This internal set stores references to registered child components that listen to dataset events.
     */
    protected elements: Set<DatasetController>;
    /**
     * This internal array stores references to child components registered as record hosts, ordered based on their DOM position.
     */
    protected recordElements: DatasetRecordHostController[];
    /**
     * This read-only set keeps track of currently selected records.
     */
    readonly selected: Set<DatasetRecord>;
    /**
     * This method dispatches a dataset event to all registered child components.
     */
    protected dispatch(event: DatasetEvent): void;
    /**
     * This flag indicates whether an update is scheduled to avoid redundant rendering calls.
     */
    protected updateScheduled: boolean;
    /**
     *  This method triggers the rendering process for the dataset and its associated records.
     */
    protected dispatchRender(): void;
    /**
     * This creates a debounced function using raf (requestAnimationFrame) to optimize rendering by batching updates.
     */
    protected renderRaf: (this: unknown) => void;
    /**
     * This internal function handles asynchronous data source updates and triggers rendering.
     */
    protected _update: (this: unknown) => void;
    /**
     * This public method initiates the data update process if a data source is defined.
     */
    update(): void;
    /**
     * This method adds a record to the selected set and triggers a render update.
     */
    select(record: DatasetRecord): void;
    /**
     *  This method removes a record from the selected set and triggers a render update.
     */
    deselect(record: DatasetRecord): void;
    /**
     * This method selects all available records and triggers a render update.
     */
    selectAll(): void;
    /**
     * This method deselects all records and triggers a render update.
     */
    deselectAll(): void;
    /**
     * This optional property allows specifying sorting criteria for the dataset.
     */
    sort?: SortState[];
    /**
     * This optional property defines a filtering function or a FilterState object to filter the dataset.
     */
    filter?: ((a: DatasetRecord) => boolean) | FilterState;
    /**
     * This optional property allows defining pagination settings for the dataset. */
    slice?: {
        page: number;
        rows: number;
    };
    /**
     * This property stores the filtered dataset length
     */
    filteredLength: number;
}
/**
 * This component serves as the foundation for components that display data in a tabular format (rows and columns).
 * It provides core functionalities for managing datasets, including data source handling, sorting, filtering, pagination, and record selection
 *
 * @beta
 * @demo
<cxl-dataset id="dataset">
    <cxl-toolbar>
        <cxl-field dense outline style="flex-grow: 1">
            <cxl-label>Search</cxl-label>
            <cxl-input id="search"></cxl-input>
        </cxl-field>
    </cxl-toolbar>
    <cxl-dataset-empty>
        <cxl-c pad="16" center>
            No Results Found
        </cxl-c>
    </cxl-dataset-empty>
    <cxl-each-record>
        <template>
            <cxl-c pad="16" vpad="8">
                <cxl-bind $text="name"></cxl-bind>,
                <cxl-bind $text="color"></cxl-bind>
            </cxl-c>
        </template>
    </cxl-each-record>
</cxl-dataset>
<script>
    dataset.source = [
        { "name": "Apple", "color": "red" },
        { "name": "Orange", "color": "green" },
        { "name": "Apple", "color": "green" },
        { "name": "Raspberry", "color": "red" },
        { "name": "Blueberry", "color": "blue" }
    ];
    search.oninput = () => { dataset.filter = { term: search.value } }
</script>
 */
export declare class Dataset extends DatasetBase {
}
/**
 * This component allows users to filter a cxl-dataset based on specific criteria.
 * It provides functionalities to define filter rules and interacts with the parent Dataset to apply filtering.
 *
 * @beta
 * @see Dataset
 */
export declare class DatasetFilter extends Component {
    /**
     * This optional property allows defining a custom filtering function that takes a data record value as input and returns true if the record should be included in the filtered results.
     */
    filter?: (value: unknown) => boolean;
    /**
     * This optional property specifies the data field in the records that the filter should be applied to.
     */
    field?: string;
    /**
     * This property stores the current filter term (e.g., search string).
     */
    term: unknown;
    /**
     * This property defines the type of filter operation to be applied to the field and term.
     */
    type: FilterState['type'];
}
export {};
