import { Component } from './component.js';
import { Checkbox } from './checkbox.js';
import { Td, Th } from './table.js';
import { DatasetBase, DatasetRecord } from './dataset.js';
declare module './registable.js' {
    interface RegistableMap {
        'datatable.column': DatatableTh;
    }
}
/**
 * A sortable table header cell within a Datatable component.
 * It allows users to display and interact with data column headers.
 *
 * @demo
 * <cxl-datatable>
 *   <cxl-tr>
 *     <cxl-dth sort="asc" field="name">Name</cxl-dth>
 *     <cxl-dth>Email</cxl-dth>
 *   </cxl-tr>
 * </cxl-datatable>
 */
export declare class DatatableTh extends Th {
    /** Defines the type of data in the column. */
    method?: 'text' | 'numeric';
    /**
     * The `sort` attribute enables column sorting functionality. Valid values are `asc`, `desc`, and `none`.
     * If left empty the value defaults to `none`.
     */
    sort?: 'asc' | 'desc' | 'none' | '' | boolean;
    /** Name of the data field in the dataset associated with this column. */
    field?: string;
    /** Whether the header cell should be hidden. */
    hidden: boolean;
    /** Indicates if multiple columns can be sorted simultaneously */
    multiple: boolean;
}
/**
 * @beta
 */
export declare class DatatableThToggle extends Checkbox {
    index?: number;
}
/**
 * A selectable table data cell that functions like a checkbox.
 * It allows users to select individual rows within a table.
 *
 * @demo
 * <cxl-datatable>
 *   <cxl-dtr source="row1">
 *     <cxl-td-select selected></cxl-td-select>
 *     <cxl-td>Row 1</cxl-td>
 *   </cxl-dtr>
 *   <cxl-dtr source="row2">
 *     <cxl-td-select></cxl-td-select>
 *     <cxl-td>Row 2</cxl-td>
 *   </cxl-dtr>
 * </cxl-datatable>
 */
export declare class TdSelect extends Td {
    /**
     * This property determines the checked state of the cell.
     */
    selected: boolean;
}
/**
 * This component represents a single data row within a Datatable component.
 * It renders the content for each table cell and manages row selection and visibility.
 *
 * @demo
 * <cxl-datatable>
 *   <cxl-dtr source="row1">
 *     <cxl-td-select></cxl-td-select>
 *     <cxl-td>Row 1</cxl-td>
 *   </cxl-dtr>
 *   <cxl-dtr source="row2">
 *     <cxl-td-select selected></cxl-td-select>
 *     <cxl-td>Row 2</cxl-td>
 *   </cxl-dtr>
 * </cxl-datatable>
 */
export declare class DatatableTr extends Component {
    /**
     * This optional property specifies a data source associated with the row.
     * This links the row to a specific data record in the underlying dataset.
     */
    source?: DatasetRecord;
}
/**
 *
 * The Datatable component builds on the functionality of a Dataset and
 * provides modular components for displaying data in a tabular format.
 * It inherits functionalities for managing datasets (source, value, selection, etc.)
 * and adds functionalities specific to table management.
 *
 * @demo
 * <cxl-datatable>
 *   <cxl-tr>
 *     <cxl-th><cxl-dataset-select-all></cxl-dataset-select-all></cxl-th>
 *     <cxl-th>Column 1</cxl-th>
 *   </cxl-tr>
 *   <cxl-dtr source="row1">
 *     <cxl-td-select></cxl-td-select>
 *     <cxl-td>Selectable Row 1</cxl-td>
 *   </cxl-dtr>
 *   <cxl-dtr source="row2">
 *     <cxl-td-select></cxl-td-select>
 *     <cxl-td>Selectable Row 2</cxl-td>
 *   </cxl-dtr>
 *   <cxl-datatable-pagination slot="footer" rows="1"></cxl-datatable-pagination>
 * </cxl-datatable>
 */
export declare class Datatable extends DatasetBase {
    /**
     * This read-only property holds an array of Th components,
     * representing the table header cells (column definitions).
     */
    readonly columns: Th[];
    protected readonly table?: HTMLTableElement;
    layout?: 'fixed' | 'auto';
    protected dispatchRender(): void;
}
