import { Component } from './component.js';
import { IconButton } from './icon-button.js';
declare module './dom.js' {
    interface CustomEventMap {
        'dialog.resolve': unknown;
    }
}
/**
 * DialogBase is an abstract class that provides a foundation for building reusable dialog components.
 * It offers functionalities for managing dialog visibility, capturing user interaction, and returning values.
 */
export declare abstract class DialogBase extends Component {
    /**
     * A reference to the underlying HTML dialog element.
     * This property is marked as readonly and cannot be modified directly.
     */
    readonly dialog: HTMLDialogElement;
    /**
     * This property stores the value to be returned by the dialog when it's closed.
     */
    returnValue: unknown;
    /**
     * A boolean attribute that determines whether the dialog is considered "static".
     * Static dialogs prevent background interaction while open.
     */
    static: boolean;
    /**
     * A boolean attribute that specifies the value to be returned when the dialog is closed via the cancel mechanism.
     */
    cancelvalue: boolean;
    /**
     * A boolean attribute that controls the visibility of the dialog. Setting this to true opens the dialog, and false closes it.
     */
    visible: boolean;
    /**
     * This method opens the dialog and returns a promise.
     * The promise resolves with the value stored in the `returnValue` property when the dialog is closed.
     * The method handles appending the dialog element to the body if it's not already attached to the DOM.
     * It also adds an event listener for the close event on the dialog element and resolves the promise with the returnValue when the event is triggered.
     */
    open(): Promise<unknown>;
}
/**
 * Provides a generic mechanism to trigger the closure of a dialog, potentially returning a specified value upon closure.
 */
export declare class DialogClose extends Component {
    /**
     * The value to be returned when the dialog is closed through this component.
     * Can be customized for different dialog actions.
     */
    closevalue: boolean;
}
/**
 * Provides a visually appealing close button with an "x" icon for closing dialogs.
 * Positions itself in the top-right corner of the dialog with a slight offset.
 *
 * <cxl-dialog visible static aria-label="demo dialog">
        <cxl-dialog-close-icon-button></cxl-dialog-close-icon-button>
        <cxl-c pad16>
        <cxl-t h5>Title</cxl-t>
        <cxl-t>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam tincidunt luctus eleifend.</cxl-t>
        </cxl-c>
    </cxl-dialog>
 */
export declare class DialogCloseIconButton extends IconButton {
    /** The name of the icon to display. */
    icon: string;
    /**
     * The value to be returned when the dialog is closed through this component.
     * Can be customized for different dialog actions.
     */
    closevalue: boolean;
}
/**
 * The Dialog component represents a modal dialog window used to inform users,
 * gather input, or present critical information.
 * It provides a dedicated space for focused interaction and can contain various content elements
 * like titles, text, buttons, and forms.
 *
 * Typical Uses:
 * - Displaying alerts, confirmations, or error messages.
 * - Presenting detailed information or instructions.
 * - Capturing user input through forms within the dialog.
 * - Highlighting important actions or choices for users.
 *
 * @demo
 * <cxl-dialog visible static aria-label="demo dialog">
        <cxl-c pad16>
        <cxl-t h5>Title</cxl-t>
        <cxl-t>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam tincidunt luctus eleifend.</cxl-t>
        </cxl-c>
    </cxl-dialog>
 */
export declare class Dialog extends DialogBase {
    /**
     * Represents a promise associated with the dialog.
     * This promise resolves with a boolean value when the dialog is closed (either confirmed or canceled).
     */
    promise?: Promise<boolean>;
}
/**
 * The alert dialog should be used for messages which do not require any
 * response on the part of the user, other than the acknowledgement of the message.
 *
 * @demo
 * <cxl-dialog-alert tabindex="-1" visible static titletext="Alert Dialog" message="Lorem ipsum dolor sit amet, consectetur adipiscing elit.">
    </cxl-dialog-alert>
 */
export declare class DialogAlert extends DialogBase {
    /**
     * The text content for the dialog's title.
     */
    titletext: string;
    /**
     * The main message or prompt displayed within the dialog.
     */
    message: string;
    /**
     * The text label for the primary action button.
     */
    action?: string;
}
/**
 * A specialized dialog component for presenting confirmation prompts to users, offering a clear choice between a primary action and a cancellation option.
 *
 * Use this component when you need to present users with a confirmation prompt and capture their binary decision (perform the action or cancel).
 *
 * @demo
 * <cxl-dialog-confirm tabindex="-1" visible static titletext="Confirmation Dialog" message="Lorem ipsum dolor sit amet, consectetur adipiscing elit.">
    </cxl-dialog-confirm>
 */
export declare class DialogConfirm extends DialogBase {
    /**
     * The text label for the cancellation button.
     */
    canceltext?: string;
    /**
     * The text content for the dialog's title.
     */
    titletext: string;
    /**
     * The main message or prompt displayed within the dialog.
     */
    message: string;
    /**
     * The text label for the primary action button.
     */
    action?: string;
}
/**
 * Presents an alert dialog to the user with a simple message and an "OK" button for dismissal.
 * @param optionsOrMessage Either a string message to display or an object containing partial properties to customize the alert dialog.
 * @param container A container element to append the dialog to. If not specified, it's appended to document.body.
 * @returns A promise that resolves when the dialog is closed, indicating that the user has acknowledged the message.
 */
export declare function alert(optionsOrMessage: string | Partial<DialogAlert>, container?: Element): Promise<unknown>;
/**
 * Presents a confirmation dialog to the user, prompting for a binary decision with two distinct buttons (e.g., "OK" and "Cancel").
 * @param options An object containing properties to customize the confirmation dialog.
 * @param container A container element to append the dialog to. If not specified, it's appended to document.body.
 * @returns A promise that resolves with a boolean value: true if the user clicked the primary action button, false if they cancelled.
 */
export declare function confirm(options: string | Partial<DialogConfirm>, container?: Element): Promise<unknown>;
