import { Observable } from './rx.js';
import { ProxiedInputBase } from './input-base.js';
export interface ValueProxyOptions<T extends TextInputBase> {
    host: T;
    input: HTMLInputElement;
    toText?(value: T['value'], old: string): string;
    toValue?(value: string): T['value'];
    update?: Observable<unknown>;
}
export declare const proxyStyle = "display:block;border:0;padding:0;font:inherit;color:var(--cxl-on-surface);outline:0;width:100%;min-height:20px;line-height:20px;background-color:transparent;text-align:left;white-space:pre-wrap;max-height:100%";
export declare function $valueProxy<T extends TextInputBase>({ host, input: el, toText, toValue, update, }: ValueProxyOptions<T>): HTMLInputElement;
/**
 * The TextInputBase class provides functionalities for text input components.
 * It offers features for handling autofill behavior, managing selection state,
 * and interacting with the browser's text selection API.
 *
 * Extend TextInputBase to create custom text input components that leverage
 * browser's autofill behavior and provide programmatic control over text selection.
 *
 */
export declare abstract class TextInputBase extends ProxiedInputBase {
    /** A boolean style attribute indicating whether the input field is currently autofilled by the browser  */
    autofilled: boolean;
    /** A string attribute specifying the type of autocomplete behavior for the input field. */
    autocomplete?: string;
    /**
     * The `commit` event is triggered when the input’s value has changed, but only after the blur
     * event or if the component is not focused. This event provides a way to handle changes that
     * occur after the user has finished interacting with the input field.
     *
     * @beta
     */
    oncommit?: (ev: CustomEvent) => void;
    /** Retrieves the current selection object from the window or shadow root */
    protected getWindowSelection(): Selection | null;
    /** Checks if the current selection originates from within the component's input element. */
    protected getOwnSelection(): Selection | undefined;
    /** Gets or sets the starting index of the current selection within the input field. */
    get selectionStart(): number | null;
    set selectionStart(n: number | null);
    /** Gets or sets the ending index of the current selection within the input field. */
    get selectionEnd(): number | null;
    set selectionEnd(n: number | null);
    /** Sets the selection range within the input field. */
    setSelectionRange(start: number | null, end: number | null): void;
}
/**
 * The Input component provides a basic input field for entering and editing text.
 * It inherits core functionalities from TextInputBase.
 *
 * @see FieldInput
 * @example
 * <cxl-field>
 * 	<cxl-label>Email Address</cxl-label>
 * 	<cxl-input value="email&#64;address.com"></cxl-input>
 * </cxl-field>
 */
export declare class Input extends TextInputBase {
    /**  A string representing the current value of the input field. */
    value: string;
    inputEl: HTMLInputElement;
}
