import { Component } from './component.js';
import { Spacing, SurfaceColorValue } from './theme.js';
export type Elevation = 0 | 1 | 2 | 3 | 4 | 5;
/**
 * The BlockBase class provides a base for building reusable UI blocks.
 * It offers styles for common properties like background color, padding, sizing, and elevation.
 */
export declare abstract class BlockBase extends Component {
    /** A boolean attribute indicating whether the block should grow to fill available space. */
    grow: boolean;
    /** A boolean attribute indicating whether the block should fill its container entirely using absolute positioning. */
    fill: boolean;
    /**
     * Responsive sizing based on screen sizes (extra small)
     * Value represent the number of grid columns to span.
     */
    xs?: number;
    /**
     * Responsive sizing based on screen sizes (small)
     * Value represent the number of grid columns to span.
     */
    sm?: number;
    /**
     * Responsive sizing based on screen sizes (medium)
     * Value represent the number of grid columns to span.
     */
    md?: number;
    /**
     * Responsive sizing based on screen sizes (large)
     * Value represent the number of grid columns to span.
     */
    lg?: number;
    /**
     * Responsive sizing based on screen sizes (extra large)
     * Value represent the number of grid columns to span.
     */
    xl?: number;
    /**
     * An attribute for applying uniform padding around the block content.
     */
    pad?: Spacing;
    /**
     * An attribute for applying vertical padding only (top and bottom).
     */
    vpad?: Spacing;
    /**
     * A color attribute allowing control over the block's background and text color.
     */
    color?: SurfaceColorValue;
    /**
     * A boolean attribute for horizontally centering the block content.
     */
    center: boolean;
    /**
     * A number attribute specifying the block's elevation shadow effect (0-5).
     */
    elevation: Elevation;
}
/**
 * The R component allows you to hide and show content based on the browser available screen space.
 * You can use it to create responsive layouts that can show or hide different content depending on the screen size.
 * You can define conditions for different screen size ranges using predefined breakpoints like _xs_ (extra small), _sm_ (small), _md_ (medium), _lg_ (large), and _xl_ (extra large). This allows you to fine-tune content visibility at specific screen widths.
 *
 * @beta
 * @demo
 * <cxl-r xs0 sm>
        <cxl-card pad16>
            <cxl-t font="code">xs0 sm</cxl-t>
            Hidden in extra small screens, visible in small to extra large screens.
        </cxl-card>
    </cxl-r>
    <cxl-r xs sm0>
        <cxl-card pad16>
            <cxl-t font="code">xs sm0</cxl-t>
            Visible only in extra small screens.
        </cxl-card>
    </cxl-r>
 */
export declare class R extends Component {
    /**
     * Attribute for defining visibility conditions at extra small screen sizes.
     * The value can be either a boolean (true/false) or a number indicating the minimum number
     * of columns to be visible (0 for hidden).
     */
    xs: 0 | boolean;
    /**
     * Attribute for defining visibility conditions at small screen sizes.
     * The value can be either a boolean (true/false) or a number indicating the minimum number
     * of columns to be visible (0 for hidden).
     */
    sm: 0 | boolean;
    /**
     * Attribute for defining visibility conditions at medium screen sizes.
     * The value can be either a boolean (true/false) or a number indicating the minimum number
     * of columns to be visible (0 for hidden).
     */
    md: 0 | boolean;
    /**
     * Attribute for defining visibility conditions at large screen sizes.
     * The value can be either a boolean (true/false) or a number indicating the minimum number
     * of columns to be visible (0 for hidden).
     */
    lg: 0 | boolean;
    /**
     * Attribute for defining visibility conditions at extra large screen sizes.
     * The value can be either a boolean (true/false) or a number indicating the minimum number
     * of columns to be visible (0 for hidden).
     */
    xl: 0 | boolean;
}
/**
 * The `<cxl-c>` component is a basic container component that provides content alignment and responsiveness. You can use it to wrap any content or other components inside it, and control how they are displayed on the screen.
 *
 * The `<cxl-c>` component offers attributes like _pad_, _vpad_, and _grow_ to control the positioning and spacing of its child elements within the container. You can further enhance the appearance of the `<cxl-c>` element using attributes like _color_ and _elevation_ to add visual cues and hierarchy to your layout.
 *
 */
export declare class C extends BlockBase {
}
/**
 * The Flex component builds upon the BlockBase class and provides additional styles and
 * attributes for creating flexible layouts using CSS flexbox.
 * It allows for dynamic content arrangement and responsiveness.
 *
 * @demo
 * <cxl-flex gap="16">
 *   <cxl-card pad16>Item 1</cxl-card>
 *   <cxl-card pad16>Item 2</cxl-card>
 *   <cxl-card pad16>Item 3</cxl-card>
 * </cxl-flex>
 */
export declare class Flex extends BlockBase {
    /**
     * A boolean attribute indicating a vertical flex layout.
     *
     * @demo
     * <cxl-flex vflex gap="8">
     *   <cxl-card pad16>Item 1</cxl-card>
     *   <cxl-card pad16>Item 2</cxl-card>
     *   <cxl-card pad16>Item 3</cxl-card>
     * </cxl-flex>
     */
    vflex: boolean;
    /**
     * A spacing attribute to control the gap between flex items using columnGap and rowGap properties.
     */
    gap?: Spacing;
    /**
     * Centers content vertically or horizontally within the flex container.
     */
    middle: boolean;
}
export type LayoutType = 'block' | 'grid' | 'two-column' | 'two-column-left' | 'two-column-right';
/**
 * The Layout component provides a flexible way to structure your UI layouts.
 * It offers predefined options and responsive styles for various layout configurations.
 *
 * @beta
 * @demo
 * <cxl-layout type="two-column">
 *    <div>Left Column Content</div>
 *    <div>Right Column Content</div>
 * </cxl-layout>
 */
export declare class Layout extends Component {
    /**
     * A string attribute defining the layout type. Options include:
     * - `block`: Creates a simple block-level container.
     * - `grid`: Creates a basic grid layout with 12 columns.
     * - `two-column`: Creates a two-column layout with equal width columns (responsive adjustments apply).
     * - `two-column-left`: Creates a two-column layout with a wider left column (responsive adjustments apply).
     * - `two-column-right`: Creates a two-column layout with a wider right column (responsive adjustments apply).
     */
    type?: LayoutType;
    /** A boolean attribute for horizontally centering the layout content. */
    center: boolean;
    /** A boolean attribute for removing width restrictions and allowing the layout to fill its container. */
    full: boolean;
}
/**
 * The Card component represents a content block focused on a single subject.
 * It provides a standard visual container for displaying information, actions,
 * and potentially an image related to that subject.
 *
 * @example
 * <cxl-card>
 *   <cxl-flex pad16 gap="24">
 *     <cxl-avatar alt="" size="1"></cxl-avatar>
 *     <cxl-c>
 *       <cxl-t subtitle>Card Title</cxl-t>
 *       <cxl-t subtitle2>Secondary Text</cxl-t>
 *     </cxl-c>
 *   </cxl-flex>
 *   <cxl-c pad16>
 *     <cxl-t>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.
 *     </cxl-t>
 *   </cxl-c>
 * </cxl-card>
 */
export declare class Card extends C {
    /**
     * Attribute that controls the card's elevation shadow effect
     */
    elevation: Elevation;
}
/**
 * The Grid component is a responsive layout grid that adapts to screen sizes and orientation, ensuring consistency across layouts. You can use it to create grid-based layouts that can arrange the content in rows and columns, with different sizes and alignments. By default the Grid component uses a 12-column grid.
 *
 * @example
 * <cxl-grid coltemplate="auto auto auto" style="color:#fff;font-family:var(--cxl-font)">
 *   <cxl-c xs1 style="background:#a00; padding: 2px">1</cxl-c>
 *   <cxl-c xs1 style="background:#0a0; padding:2px">2</cxl-c>
 *   <cxl-c xs1 style="background:#0a0; padding:2px">3</cxl-c>
 *   <cxl-c xs2 style="background:#00a; padding:2px">4</cxl-c>
 *   <cxl-c xs1 style="background:#00a; padding:2px">5</cxl-c>
 * </cxl-grid>
 */
export declare class Grid extends Component {
    /**
     * A number attribute specifying the number of rows in the grid.
     */
    rows?: number;
    /**
     * A number or string attribute defining the number of columns (e.g., 12)
     * or using the special value "auto-fill" to distribute available space evenly.
     * Defaults to 12 columns.
     */
    columns: number | 'auto-fill';
    /**
     * A string attribute for defining a custom column template using CSS grid syntax
     * (e.g., "repeat(4, 1fr)" for four equal-width columns).
     */
    coltemplate?: string;
}
/**
 * The Section component builds upon the Layout component and provides a styled section
 * element for structuring your UI content.
 * It offers a standard visual container with padding and background color options.
 *
 * @beta
 * @demo
 * <cxl-section dense color="primary">
 *   <cxl-t h4>Section Title</cxl-t>
 *   <p>Content with a primary background color.</p>
 * </cxl-section>
 */
export declare class Section extends Layout {
    /** A boolean attribute for a more compact section with reduced padding. */
    dense: boolean;
    /**
     * A color attribute allowing you to customize the section's background color based on the theme.
     */
    color?: SurfaceColorValue;
    center: boolean;
    type: LayoutType | undefined;
}
export declare class Body extends Component {
    center: boolean;
}
export declare class Page extends Layout {
    type: LayoutType | undefined;
}
