import { DateFormat } from './datetime.js';
import type { ValidationContent } from './validation';
import type { TimepickerContent } from './input-timepicker';
import type { BreakpointKey } from './css';
export type LocaleName = 'default' | 'en' | 'es' | 'fr';
/**
 * The LocaleBase class serves as a foundation for building localized UI components.
 */
export declare abstract class LocaleBase {
    /**
     * This abstract property defines the content specific to a particular locale.
     */
    abstract readonly content: LocaleContent;
    /**
     * This abstract property specifies the name of the locale (e.g., "en", "de").
     */
    abstract readonly name: LocaleName;
    abstract currencyCode: string;
    /**
     * This property allows overriding the default locale.
     */
    abstract localeName: string;
    abstract decimalSeparator: string;
    /**
     * This method formats a Date object according to the specified locale. It takes two arguments:
     * @param date     The Date object to be formatted.
     * @param options  An object or string defining the desired date format. If options is a string, it's assumed to be a preset format name supported by the implementation (e.g., "short", "long"). If options is an object, it's passed directly to the toLocaleString method of the Date object, using the localeName for locale-specific formatting.
     *
     */
    formatDate(date: Date, options?: DateFormat): string;
}
export type ContentKeys = keyof typeof defaultContent | 'calendar.month' | 'calendar.week' | 'calendar.day' | 'calendar.next' | 'calendar.previous' | 'carousel.previous' | 'carousel.next' | 'carousel.pagination' | 'carousel.paginationitem' | 'colorpicker.hue' | 'colorpicker.alpha' | 'colorpicker.hex' | 'colorpicker.red' | 'colorpicker.green' | 'colorpicker.blue' | 'datepicker.open' | 'datepicker.close' | 'datepicker.nextYearPage' | 'datepicker.nextMonth' | 'datepicker.previousYearPage' | 'datepicker.previousMonth' | 'datepicker.openYearPanel' | 'datepicker.closeYearPanel' | 'dataset.selectAll' | 'dataset.deselectAll' | 'datatable.selectRow' | 'datatable.rpp' | 'datatable.columnSort' | 'dialog.close' | 'dialog.cancel' | 'dialog.ok' | 'field.clear' | 'navigation.goPrevious' | 'navigation.goNext' | 'navigation.goFirst' | 'navigation.goLast' | 'password-reveal.on' | 'password-reveal.off' | keyof typeof ValidationContent | keyof typeof TimepickerContent;
export type LocaleContent = Record<ContentKeys, string>;
declare const defaultContent: {
    'core.enable': string;
    'core.disable': string;
    'core.open': string;
    'core.of': string;
};
/**
 * The DefaultLocale class extends the abstract LocaleBase class and provides a concrete implementation
 * for the default locale (English).
 */
export declare class DefaultLocale extends LocaleBase {
    content: LocaleContent;
    name: LocaleName;
    localeName: string;
    currencyCode: string;
    decimalSeparator: string;
}
export declare class EnglishLocale extends LocaleBase {
    content: LocaleContent;
    name: LocaleName;
    localeName: string;
    currencyCode: string;
    decimalSeparator: string;
}
export declare function ContentManager(): {
    /** An observable stream that emits the current locale's content dictionary. */
    content: import("./rx.js").Observable<LocaleContent, "none">;
    /** A registry containing instances of all registered locales */
    registeredLocales: Partial<Record<string, LocaleBase>>;
    locale: import("./rx.js").BehaviorSubject<LocaleBase>;
    setLocale: (localeId: LocaleName) => Promise<void>;
    /** Retrieves localized text for a given key from the current locale's content. */
    get(key: ContentKeys, fallbackKey?: ContentKeys): import("./rx.js").Observable<string, "none">;
    /** Registers a new locale with the manager. */
    register(locale: LocaleBase): void;
};
export declare const content: {
    /** An observable stream that emits the current locale's content dictionary. */
    content: import("./rx.js").Observable<LocaleContent, "none">;
    /** A registry containing instances of all registered locales */
    registeredLocales: Partial<Record<string, LocaleBase>>;
    locale: import("./rx.js").BehaviorSubject<LocaleBase>;
    setLocale: (localeId: LocaleName) => Promise<void>;
    /** Retrieves localized text for a given key from the current locale's content. */
    get(key: ContentKeys, fallbackKey?: ContentKeys): import("./rx.js").Observable<string, "none">;
    /** Registers a new locale with the manager. */
    register(locale: LocaleBase): void;
};
export declare function registerText(newContent: Partial<LocaleContent>): (key: ContentKeys, fallbackKey?: ContentKeys) => import("./rx.js").Observable<string, "none">;
export declare function formatDate(options?: DateFormat): (v: Date | undefined) => import("./rx.js").Observable<string, "none">;
export declare function getDayText(day: number, size: BreakpointKey): import("./rx.js").Observable<string, "none">;
export {};
