import { Component, Span } from './component.js';
import { Observable } from './rx.js';
import { AnimationKey } from './theme.js';
import { ToggleTarget } from './toggle.js';
import { IconButton } from './icon-button.js';
import type { Elevation } from './layout.js';
declare module './dom.js' {
    interface CustomEventMap {
        'popup.visible': boolean;
    }
}
export type PopupPosition = 'right top' | 'right bottom' | 'left top' | 'left bottom' | 'center top' | 'center bottom' | 'fill bottom' | 'auto' | 'none';
interface PositionOptions {
    element: HTMLElement;
    relativeTo: Element;
    position: PopupPosition | ((el: HTMLElement) => void);
    container?: HTMLElement;
    offsetX?: number;
}
interface OpenPopupOptions {
    element: ToggleTarget;
    close(): void;
}
export declare class Surrogate extends Component {
    target?: Element;
}
/**
 * Closes a popup on click.
 *
 * @beta
 * @example
 * <cxl-popup visible animationin="">
 *   <cxl-popup-close>
 *     <cxl-button>Close</cxl-button>
 *   </cxl-popup-close>
 * </cxl-popup>
 */
export declare class PopupClose extends Component {
}
export declare function popupToggleBehavior<T extends PopupToggle>($: T): Observable<unknown, "none">;
/**
 * This component, cxl-popup-toggle, manages the visibility of a popup container based on user interaction.
 *
 * @demo
 * <cxl-popup-toggle target="popup">
 *   <cxl-button>Open</cxl-button>
 * </cxl-popup-toggle>
 * <cxl-popup aria-label="target popup" id="popup">
 *   <cxl-c pad32 elevation="3">Popup</cxl-c>
 * </cxl-popup>
 */
export declare class PopupToggle extends Component {
    /** A boolean style attribute indicating the popup's current visibility state (opened or closed). */
    opened: boolean;
    /** An attribute referencing the ID of the popup element it controls or a ToggleTarget object. */
    target?: string | ToggleTarget;
    /** An element to position the popup relative to. */
    relative?: Element;
    position?: PopupPosition | ((el: HTMLElement) => void);
}
/**
 * The PopupIconToggle component inherits from IconButton and adds popup toggle functionality specifically
 * using an icon button. It builds upon the PopupToggle component with additional features.
 *
 * @example
 * <cxl-popup-icon-toggle title="Open Menu" target="menu1"></cxl-popup-icon-toggle>
 * <cxl-menu id="menu1">
 *   <cxl-item>Home</cxl-item>
 *   <cxl-item>Support</cxl-item>
 * </cxl-menu>
 */
export declare class PopupIconToggle extends IconButton {
    /**
     * Defines the icon to display on the button
     */
    icon: string;
    /** A boolean style attribute indicating the popup's current visibility state (opened or closed). */
    opened: boolean;
    /** An attribute referencing the ID of the popup element it controls or a ToggleTarget object. */
    target?: string | ToggleTarget;
    /** An element to position the popup relative to. */
    relative?: Element;
    position?: PopupPosition | ((el: HTMLElement) => void);
}
/**
 * The PopupBase component serves as the foundation for creating popup elements.
 * It manages the visibility state of the popup and provides animations for opening and closing.
 */
export declare class PopupBase extends Component {
    /** Controls the visibility of the popup (opened or closed). */
    visible: boolean;
    /** Defines the animation to play when opening the popup */
    animationin?: AnimationKey;
    /** Defines the animation to play when closing the popup  */
    animationout?: AnimationKey;
    /** A flag indicating whether to focus on the first focusable element within the popup when it opens. */
    handleFocus: boolean;
}
/**
 * The Window component builds upon the cxl-popup-base functionality to create a modal window element.
 * It represents a popup with a higher visual importance, often used for dialogs or critical information.
 */
export declare class Window extends PopupBase {
    /**  Controls the level of shadow applied to the window, creating a depth effect (0-5). */
    elevation: number;
}
export declare function popupBehavior($: PopupBase): Observable<MouseEvent | KeyboardEvent, "none">;
/**
 * The Popup component is a popup element that incorporates the functionalities of Window and PopupBase.
 * It provides a modal window with a defined look and feel, commonly used for displaying informative content or user interactions.
 *
 * @beta
 * @demo
 * <cxl-popup-toggle target="popup">
 *   <cxl-button>Open</cxl-button>
 * </cxl-popup-toggle>
 * <cxl-popup aria-label="target popup" id="popup" elevation="2">Popup</cxl-popup>
 */
export declare class Popup extends Window {
    /** Defaults to 'fadeIn' animation when opening the popup. */
    animationin?: AnimationKey;
    /** Defaults to 'fadeOut' animation when closing the popup. */
    animationout?: AnimationKey;
    /** Defaults to an elevation of 1 (can be overridden). */
    elevation: Elevation;
    /** Sets focus on the first focusable element within the popup when it opens (default behavior). */
    handleFocus: boolean;
}
export declare function positionElement({ element, relativeTo, position, container, offsetX, }: PositionOptions): void;
declare class PopupManager {
    currentPopupContainer?: HTMLElement;
    currentPopup?: OpenPopupOptions;
    currentModal?: {
        element: HTMLDialogElement & {
            popupContainer?: Span;
        };
        close: () => void;
    };
    currentTooltip?: HTMLElement;
    popupContainer?: Span;
    toggle(options: OpenPopupOptions): void;
    popupOpened(options: OpenPopupOptions): void;
    openModal(options: {
        element: HTMLDialogElement;
        close: () => void;
    }): void;
    closeModal(): void;
    modalClosed(): void;
    tooltipOpened(element: HTMLElement): void;
    close(): void;
}
export declare const popupManager: PopupManager;
export {};
