import { Component } from './component.js';
declare module './registable.js' {
    interface RegistableMap {
        tabs: BaseTab;
    }
}
/**
 * The BaseTab class is an abstract component that serves as the foundation for building tab UIs.
 */
export declare abstract class BaseTab extends Component {
    /**
     * A boolean attribute indicating whether the tab is currently selected.
     */
    selected: boolean;
    touched: boolean;
    /**
     * A boolean attribute indicating if the tab is disabled.
     */
    disabled: boolean;
    /**
     * An optional string attribute allowing you to assign a name to the tab.
     * This name is used for accessibility and programmatic selection.
     */
    name?: string;
}
/**
 * Tabs organize content across different screens, data sets, and other interactions.
 * @example
<cxl-tabs>
    <cxl-tab name="tab1" selected>Tab 1</cxl-tab>
    <cxl-tab name="tab2">Tab 2</cxl-tab>
    <cxl-tab name="tab3">Tab 3</cxl-tab>
</cxl-tabs>
 * @see Tabs
 */
export declare class Tab extends BaseTab {
}
/**
 * The Tabs component implements a tabbed interface for organizing content across different sections within your application.
 *
 * @example
<cxl-tabs>
    <cxl-tab name="tab1" selected>Tab 1</cxl-tab>
    <cxl-tab name="tab2">Tab 2</cxl-tab>
    <cxl-tab name="tab3">Tab 3</cxl-tab>
</cxl-tabs>
 * @see Tab
 */
export declare class Tabs extends Component {
    /**
     * This attribute specifies the currently selected tab within the Tabs component.
     * It should reference a Tab element from within the tabs container.
     */
    selected?: Tab;
    /**
     * This property holds a Set containing all the Tab elements nested within the Tabs component.
     */
    tabs: Set<BaseTab>;
    /**
     * This style attribute allows you to control whether the tab container fills
     * the available horizontal space. Set grow to true for tabs to stretch and fill the container's width.
     */
    grow: boolean;
}
/**
 * The TabPanel class represents a content panel associated with a specific tab
 *
 * @example
<cxl-tabs id="tabs-el">
    <cxl-tab name="tab1">Tab 1</cxl-tab>
    <cxl-tab selected name="tab2">Tab 2</cxl-tab>
    <cxl-tab name="tab3">Tab 3</cxl-tab>
</cxl-tabs>
<cxl-tab-panel tabs="tabs-el" name="tab1"><cxl-c pad="16">Tab Panel 1</cxl-c></cxl-tab-panel>
<cxl-tab-panel tabs="tabs-el" name="tab2"><cxl-c pad="16">Tab Panel 2</cxl-c></cxl-tab-panel>
<cxl-tab-panel tabs="tabs-el" name="tab3"><cxl-c pad="16">Tab Panel 3</cxl-c></cxl-tab-panel>
 * @see Tabs
 */
export declare class TabPanel extends Component {
    /**
     * A read-only boolean attribute reflecting the visibility state of the panel.
     */
    readonly visible = false;
    /**
     * An optional attribute that specifies the ID of the associated Tabs component or a reference to the Tabs component itself.
     * This creates a link between the panel and the tabs it belongs to.
     */
    tabs?: Tabs | string;
    /**
     * An optional string attribute for the panel. This name is used to match it with the corresponding
     * tab based on the name attribute of the BaseTab component.
     */
    name?: string;
}
