import { Observable } from './rx.js';
import type { InputBase } from './input-base.js';
/**
 * A function that takes a value and returns a boolean or an Observable indicating whether the value is valid.
 */
export type Rule = (val: unknown) => boolean | Observable<boolean>;
export type RuleWithParameter = (param: string) => Rule;
export type Validator = (val: unknown) => Observable<ValidationResult> | Promise<ValidationResult> | ValidationResult;
export type RuleKey = 'json' | 'zipcode' | 'equalTo' | 'required' | 'notZero' | 'email' | 'pattern' | 'min' | 'greaterThan' | 'max' | 'lessThan';
export interface ValidationResult {
    valid: boolean;
    key?: string;
    message?: string | Observable<string>;
}
export declare const ValidationContent: {
    'validation.invalid': string;
    'validation.json': string;
    'validation.zipcode': string;
    'validation.equalTo': string;
    'validation.required': string;
    'validation.notZero': string;
    'validation.email': string;
    'validation.pattern': string;
    'validation.min': string;
    'validation.max': string;
    'validation.greaterThan': string;
    'validation.lessThan': string;
};
/**
 * Checks if a value is empty (null, undefined, empty string, false, or an empty array).
 */
export declare function empty(val: unknown): boolean;
/**
 * Creates a rule that checks if a string matches a regular expression.
 */
export declare function pattern(regex: RegExp | string): (val: unknown) => ValidationResult;
/**
 * Checks if a value is not empty.
 */
export declare function required(val: unknown): ValidationResult;
/**
 * Checks if a value is a valid email address.
 */
export declare function email(val: unknown): ValidationResult;
/**
 * Checks if a value is a valid US zip code.
 */
export declare function zipcode(val: unknown): ValidationResult;
/**
 * Checks if a value is valid JSON.
 */
export declare function validJson(val: unknown): boolean;
export declare function json(val: unknown): ValidationResult;
/**
 * Creates a rule that compares a value to another value or observable.
 */
export declare function compare(key: RuleKey, b: InputBase | Observable<unknown> | unknown, fn: (a: unknown, b: unknown) => boolean, msg?: string): (a: unknown) => Observable<ValidationResult, "none">;
/**
 * Parses a string or array of rules into a Validator function.
 */
export declare function parseRules(ruleList: string | Array<string | Validator>): (val: unknown) => Observable<ValidationResult, "none">[];
/**
 * Creates a rule that checks if a value is greater than or equal to another value or observable.
 */
export declare function min(val: InputBase | Observable<unknown> | unknown, msg?: string): (a: unknown) => Observable<ValidationResult, "none">;
/**
 * Creates a rule that checks if a value is greater than another value or observable.
 */
export declare function greaterThan(val: InputBase | Observable<unknown> | unknown, msg?: string): (a: unknown) => Observable<ValidationResult, "none">;
/**
 * Creates a rule that checks if a value is less than or equal to another value or observable.
 */
export declare function max(val: InputBase | Observable<unknown> | unknown, msg?: string): (a: unknown) => Observable<ValidationResult, "none">;
/**
 * Creates a rule that checks if a value is less than another value or observable.
 */
export declare function lessThan(val: InputBase | Observable<unknown> | unknown, msg?: string): (a: unknown) => Observable<ValidationResult, "none">;
/**
 * Creates a rule that checks if a value is equal to another value or observable.
 */
export declare function equalTo(val: InputBase | Observable<unknown> | unknown, msg?: string): (a: unknown) => Observable<ValidationResult, "none">;
/**
 * Creates a rule that checks if a string's length is less than or equal to a specified length.
 */
export declare function maxlength(len: number | string, message?: string): (a: unknown) => {
    key: string;
    valid: boolean;
    message: string | undefined;
};
/**
 * Creates a rule that checks if a string's length is greater than or equal to a specified length.
 */
export declare function minlength(len: number | string, message?: string): (a: unknown) => {
    key: string;
    valid: boolean;
    message: string | undefined;
};
/**
 * @param element Element or Selector
 */
export declare const equalToElement: (val: unknown, msg?: string) => Validator;
export declare const rules: {
    required: typeof required;
    email: typeof email;
    json: typeof json;
    zipcode: typeof zipcode;
};
export declare const rulesWithParameters: {
    pattern: typeof pattern;
    equalToElement: (val: unknown, msg?: string) => Validator;
    greaterThanElement: (val: unknown, msg?: string) => Validator;
    min: typeof min;
    max: typeof max;
    equalTo: typeof equalTo;
    maxlength: typeof maxlength;
    minlength: typeof minlength;
};
